@@ -12,7 +12,7 @@ short_description: Create or delete AWS AutoScaling Groups (ASGs)
 description:
   - Can create or delete AWS AutoScaling Groups.
   - Can be used with the M(community.aws.autoscaling_launch_config) module to manage Launch Configurations.
-  - Prior to release 5.0.0 this module was called C(community.aws.ec2_asg).
+  - Prior to release 5.0.0 this module was called M(community.aws.ec2_asg).
     The usage did not change.
   - This module was originally added to C(community.aws) in release 1.0.0.
 author:
@@ -27,6 +27,7 @@ options:
   name:
     description:
       - Unique name for group to be created or deleted.
+    aliases: ['group_name']
     required: true
     type: str
   load_balancers:
@@ -42,17 +43,20 @@ options:
   availability_zones:
     description:
       - List of availability zone names in which to create the group.
-      - Defaults to all the availability zones in the region if I(vpc_zone_identifier) is not set.
+      - Defaults to all the availability zones in the region if O(vpc_zone_identifier) is not set.
     type: list
     elements: str
   launch_config_name:
     description:
-      - Name of the Launch configuration to use for the group. See the community.aws.autoscaling_launch_config) module for managing these.
-      - If unspecified then the current group value will be used.  One of I(launch_config_name) or I(launch_template) must be provided.
+      - Name of the Launch configuration to use for the group. See the M(community.aws.autoscaling_launch_config) module for managing these.
+      - Exactly one of O(launch_config_name) or O(launch_template) must be provided when creating a new AutoScaling Group.
+      - B(Note) Amazon has deprecated support for AutoScaling Launch Configurations in favour of EC2 Launch Templates.  See
+        U(https://docs.aws.amazon.com/autoscaling/ec2/userguide/launch-configurations.html) for more information
     type: str
   launch_template:
     description:
-      - Dictionary describing the Launch Template to use
+      - Dictionary describing the Launch Template to use.
+      - Exactly one of O(launch_config_name) or O(launch_template) must be provided when creating a new AutoScaling Group.
     suboptions:
       version:
         description:
@@ -61,11 +65,11 @@ options:
         type: str
       launch_template_name:
         description:
-          - The name of the launch template. Only one of I(launch_template_name) or I(launch_template_id) is required.
+          - The name of the launch template. Only one of O(launch_template.launch_template_name) or O(launch_template.launch_template_id) is required.
         type: str
       launch_template_id:
         description:
-          - The id of the launch template. Only one of I(launch_template_name) or I(launch_template_id) is required.
+          - The id of the launch template. Only one of O(launch_template.launch_template_name) or O(launch_template.launch_template_id) is required.
         type: str
     type: dict
   min_size:
@@ -79,19 +83,19 @@ options:
   max_instance_lifetime:
     description:
       - The maximum amount of time, in seconds, that an instance can be in service.
-      - Maximum instance lifetime must be equal to 0, between 604800 and 31536000 seconds (inclusive), or not specified.
-      - Value of 0 removes lifetime restriction.
+      - Maximum instance lifetime must be equal to V(0), between V(604800) and V(31536000) seconds (inclusive), or not specified.
+      - Value of V(0) removes lifetime restriction.
     type: int
   mixed_instances_policy:
     description:
       - A mixed instance policy to use for the ASG.
-      - Only used when the ASG is configured to use a Launch Template (I(launch_template)).
+      - Only used when the ASG is configured to use a Launch Template (O(launch_template)).
       - 'See also U(https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-mixedinstancespolicy.html)'
     required: false
     suboptions:
       instance_types:
         description:
-          - A list of instance_types.
+          - A list of instance types.
         type: list
         elements: str
         required: false
@@ -120,17 +124,19 @@ options:
                 The minimum amount of the Auto Scaling group's capacity that must be fulfilled by On-Demand
                 Instances. This base portion is provisioned first as your group scales.
               - >-
-                Default if not set is 0. If you leave it set to 0, On-Demand Instances are launched as a
-                percentage of the Auto Scaling group's desired capacity, per the OnDemandPercentageAboveBaseCapacity setting.
+                Default if not set is V(0). If you leave it set to V(0), On-Demand Instances are launched as a
+                percentage of the Auto Scaling group's desired capacity, per the
+                O(mixed_instances_policy.instances_distribution.on_demand_percentage_above_base_capacity) setting.
             type: int
             required: false
             version_added: 1.5.0
             version_added_collection: community.aws
           on_demand_percentage_above_base_capacity:
             description:
-              - Controls the percentages of On-Demand Instances and Spot Instances for your additional capacity beyond OnDemandBaseCapacity.
-              - Default if not set is 100. If you leave it set to 100, the percentages are 100% for On-Demand Instances and 0% for Spot Instances.
-              - 'Valid range: 0 to 100'
+              - Controls the percentages of On-Demand Instances and Spot Instances for your additional capacity beyond
+                O(mixed_instances_policy.instances_distribution.on_demand_base_capacity).
+              - Default if not set is V(100). If you leave it set to V(100), the percentages are 100% for On-Demand Instances and 0% for Spot Instances.
+              - 'Valid range: V(0) to V(100).'
             type: int
             required: false
             version_added: 1.5.0
@@ -146,9 +152,9 @@ options:
             description:
               - >-
                 The number of Spot Instance pools across which to allocate your Spot Instances. The Spot pools are determined from
-                the different instance types in the Overrides array of LaunchTemplate. Default if not set is 2.
+                the different instance types in the Overrides array of LaunchTemplate. Default if not set is V(2).
               - Used only when the Spot allocation strategy is lowest-price.
-              - 'Valid Range: Minimum value of 1. Maximum value of 20.'
+              - 'Valid Range: Minimum value of V(1). Maximum value of V(20).'
             type: int
             required: false
             version_added: 1.5.0
@@ -173,29 +179,45 @@ options:
     type: int
   replace_all_instances:
     description:
+      - Support for the O(replace_all_instances) parameter has been deprecated and will be removed
+        in release 14.0.0.
+        The M(amazon.aws.autoscaling_instance_refresh) module can be used to perform an automated
+        replacement of instances.
       - In a rolling fashion, replace all instances that used the old launch configuration with one from the new launch configuration.
-        It increases the ASG size by I(replace_batch_size), waits for the new instances to be up and running.
+        It increases the ASG size by O(replace_batch_size), waits for the new instances to be up and running.
         After that, it terminates a batch of old instances, waits for the replacements, and repeats, until all old instances are replaced.
         Once that's done the ASG size is reduced back to the expected size.
     default: false
     type: bool
   replace_batch_size:
     description:
-      - Number of instances you'd like to replace at a time.  Used with I(replace_all_instances).
+      - Support for the O(replace_all_instances) and O(replace_batch_size) parameters has been
+        deprecated and will be removed in release 14.0.0.
+        The M(amazon.aws.autoscaling_instance_refresh) module can be used to perform an automated
+        replacement of instances.
+      - Number of instances you'd like to replace at a time.  Used with O(replace_all_instances).
     required: false
     default: 1
     type: int
   replace_instances:
     description:
-      - List of I(instance_ids) belonging to the named AutoScalingGroup that you would like to terminate and be replaced with instances
+      - Support for the O(replace_instances) parameter has been deprecated and will be removed in
+        release 14.0.0.
+        The M(amazon.aws.autoscaling_instance) module can be used to terminate instances attached
+        to an AutoScaling Group.
+      - List of instance ids belonging to the named AutoScalingGroup that you would like to terminate and be replaced with instances
         matching the current launch configuration.
     type: list
     elements: str
     default: []
   detach_instances:
     description:
+      - Support for the O(detach_instances) parameter has been deprecated and will be removed in
+        release 14.0.0.
+        The M(amazon.aws.autoscaling_instance) module can be used to attach instances to and detach
+        and detach instances from an AutoScaling Group.
       - Removes one or more instances from the specified AutoScalingGroup.
-      - If I(decrement_desired_capacity) flag is not set, new instance(s) are launched to replace the detached instance(s).
+      - If O(decrement_desired_capacity) flag is not set, new instance(s) are launched to replace the detached instance(s).
       - If a Classic Load Balancer is attached to the AutoScalingGroup, the instances are also deregistered from the load balancer.
       - If there are target groups attached to the AutoScalingGroup, the instances are also deregistered from the target groups.
     type: list
@@ -205,6 +227,10 @@ options:
     version_added_collection: community.aws
   decrement_desired_capacity:
     description:
+      - Support for the O(detach_instances) and O(decrement_desired_capacity) parameters has been
+        deprecated and will be removed in release 14.0.0.
+        The M(amazon.aws.autoscaling_instance) module can be used to attach instances to and detach
+        and detach instances from an AutoScaling Group.
       - Indicates whether the AutoScalingGroup decrements the desired capacity value by the number of instances detached.
     default: false
     type: bool
@@ -212,13 +238,21 @@ options:
     version_added_collection: community.aws
   lc_check:
     description:
-      - Check to make sure instances that are being replaced with I(replace_instances) do not already have the current I(launch_config).
+      - Support for the O(detach_instances) and O(lc_check) parameters has been deprecated and will
+        be removed in release 14.0.0.
+        The M(amazon.aws.autoscaling_instance) module can be used to attach instances to and detach
+        and detach instances from an AutoScaling Group.
+      - Check to make sure instances that are being replaced with O(replace_instances) do not already have the current launch config.
     default: true
     type: bool
   lt_check:
     description:
-      - Check to make sure instances that are being replaced with I(replace_instances) do not already have the current
-        I(launch_template or I(launch_template) I(version).
+      - Support for the O(detach_instances) and O(lt_check) parameters has been deprecated and will
+        be removed in release 14.0.0.
+        The M(amazon.aws.autoscaling_instance) module can be used to attach instances to and detach
+        and detach instances from an AutoScaling Group.
+      - Check to make sure instances that are being replaced with O(replace_instances) do not already have the current
+        O(launch_template) or O(launch_template) O(launch_template.version).
     default: true
     type: bool
   vpc_zone_identifier:
@@ -229,15 +263,15 @@ options:
   tags:
     description:
       - A list of tags to add to the Auto Scale Group.
-      - Optional key is I(propagate_at_launch), which defaults to true.
-      - When I(propagate_at_launch) is true the tags will be propagated to the Instances created.
+      - Optional key is V(propagate_at_launch), which defaults to V(true).
+      - When V(propagate_at_launch) is V(true) the tags will be propagated to the Instances created.
     type: list
     elements: dict
     default: []
   purge_tags:
     description:
-      - If C(true), existing tags will be purged from the resource to match exactly what is defined by I(tags) parameter.
-      - If the I(tags) parameter is not set then tags will not be modified.
+      - If V(true), existing tags will be purged from the resource to match exactly what is defined by O(tags) parameter.
+      - If the O(tags) parameter is not set then tags will not be modified.
     default: false
     type: bool
     version_added: 3.2.0
@@ -275,9 +309,9 @@ options:
   termination_policies:
     description:
         - An ordered list of criteria used for selecting instances to be removed from the Auto Scaling group when reducing capacity.
-        - Using I(termination_policies=Default) when modifying an existing AutoScalingGroup will result in the existing policy being retained
-          instead of changed to C(Default).
-        - 'Valid values include: C(Default), C(OldestInstance), C(NewestInstance), C(OldestLaunchConfiguration), C(ClosestToNextInstanceHour)'
+        - Using O(termination_policies=Default) when modifying an existing AutoScalingGroup will result in the existing policy being retained
+          instead of changed to V(Default).
+        - 'Valid values include: V(Default), V(OldestInstance), V(NewestInstance), V(OldestLaunchConfiguration), V(ClosestToNextInstanceHour)'
         - 'Full documentation of valid values can be found in the AWS documentation:'
         - 'U(https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-instance-termination.html#custom-termination-policy)'
     default: Default
@@ -302,7 +336,7 @@ options:
     description:
       - A list of scaling processes to suspend.
       - 'Valid values include:'
-      - C(Launch), C(Terminate), C(HealthCheck), C(ReplaceUnhealthy), C(AZRebalance), C(AlarmNotification), C(ScheduledActions), C(AddToLoadBalancer)
+      - V(Launch), V(Terminate), V(HealthCheck), V(ReplaceUnhealthy), V(AZRebalance), V(AlarmNotification), V(ScheduledActions), V(AddToLoadBalancer)
       - 'Full documentation of valid values can be found in the AWS documentation:'
       - 'U(https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-suspend-resume-processes.html)'
     default: []
@@ -315,12 +349,12 @@ options:
     default: false
   metrics_granularity:
     description:
-      - When I(metrics_collection=true) this will determine the granularity of metrics collected by CloudWatch.
+      - When O(metrics_collection=true) this will determine the granularity of metrics collected by CloudWatch.
     default: "1Minute"
     type: str
   metrics_list:
     description:
-      - List of autoscaling metrics to collect when I(metrics_collection=true).
+      - List of autoscaling metrics to collect when O(metrics_collection=true).
     default:
       - 'GroupMinSize'
       - 'GroupMaxSize'
@@ -339,110 +373,102 @@ extends_documentation_fragment:
 """
 
 EXAMPLES = r"""
-# Basic configuration with Launch Configuration
+# Basic configuration with Launch Template
 
-- amazon.aws.autoscaling_group:
-    name: special
-    load_balancers: [ 'lb1', 'lb2' ]
-    availability_zones: [ 'eu-west-1a', 'eu-west-1b' ]
-    launch_config_name: 'lc-1'
+- name: Create an autoscaling group using launch template
+  amazon.aws.autoscaling_group:
+    name: example_asg
+    load_balancers: ['lb1', 'lb2']
+    availability_zones: ['eu-west-1a', 'eu-west-1b']
+    launch_template:
+      launch_template_name: 'template-1'
     min_size: 1
     max_size: 10
     desired_capacity: 5
-    vpc_zone_identifier: [ 'subnet-abcd1234', 'subnet-1a2b3c4d' ]
+    vpc_zone_identifier: ['subnet-abcd1234', 'subnet-1a2b3c4d']
     tags:
       - environment: production
         propagate_at_launch: false
 
 # Rolling ASG Updates
 
-# Below is an example of how to assign a new launch config to an ASG and terminate old instances.
-#
-# All instances in "myasg" that do not have the launch configuration named "my_new_lc" will be terminated in
-# a rolling fashion with instances using the current launch configuration, "my_new_lc".
-#
-# This could also be considered a rolling deploy of a pre-baked AMI.
-#
-# If this is a newly created group, the instances will not be replaced since all instances
-# will have the current launch configuration.
+# Below is an example of how to assign a new launch template to an ASG and replace old instances.
+# By setting max_healthy_percentage to a value over 100 the old rolling-replacement behaviour of
+# scaling up before scaling in can be maintained.
 
-- name: create launch config
-  community.aws.autoscaling_launch_config:
-    name: my_new_lc
-    image_id: ami-lkajsf
-    key_name: mykey
-    region: us-east-1
-    security_groups: sg-23423
-    instance_type: m1.small
-    assign_public_ip: true
-
-- amazon.aws.autoscaling_group:
-    name: myasg
-    launch_config_name: my_new_lc
+- name: Update autoscaling group with new template - instances are not replaced
+  amazon.aws.autoscaling_group:
+    name: example_asg
+    launch_template:
+      launch_template_name: template-2
     health_check_period: 60
     health_check_type: ELB
-    replace_all_instances: true
-    min_size: 5
-    max_size: 5
-    desired_capacity: 5
+    min_size: 2
+    max_size: 13
+    desired_capacity: 6
     region: us-east-1
 
-# To only replace a couple of instances instead of all of them, supply a list
-# to "replace_instances":
+- name: Replace 2 instances based on EC2 Instance ID by marking them for termination
+  amazon.aws.autoscaling_instance:
+    group_name: example_asg
+    state: terminated
+    instance_ids:
+      - i-b345231
+      - i-24c2931
+    decrement_desired_capacity: false
+    wait: true
 
-- amazon.aws.autoscaling_group:
-    name: myasg
-    launch_config_name: my_new_lc
-    health_check_period: 60
-    health_check_type: ELB
-    replace_instances:
-    - i-b345231
-    - i-24c2931
-    min_size: 5
-    max_size: 5
-    desired_capacity: 5
-    region: us-east-1
+- name: Trigger rolling replacement of all instances that do not match the current configuration.
+  amazon.aws.autoscaling_instance_refresh:
+    group_name: example_asg
+    state: started
+    strategy: Rolling
+    preferences:
+      skip_matching: true
+      max_healthy_percentage: 125  # scale out before terminating instances during replacement
 
 # Basic Configuration with Launch Template
 
-- amazon.aws.autoscaling_group:
-    name: special
-    load_balancers: [ 'lb1', 'lb2' ]
-    availability_zones: [ 'eu-west-1a', 'eu-west-1b' ]
+- name: Example autoscaling group creation with a launch template
+  amazon.aws.autoscaling_group:
+    name: example_with_template
+    load_balancers: ['lb1', 'lb2']
+    availability_zones: ['eu-west-1a', 'eu-west-1b']
     launch_template:
-        version: '1'
-        launch_template_name: 'lt-example'
-        launch_template_id: 'lt-123456'
+      version: '1'
+      launch_template_name: 'lt-example'
+      launch_template_id: 'lt-123456'
     min_size: 1
     max_size: 10
     desired_capacity: 5
-    vpc_zone_identifier: [ 'subnet-abcd1234', 'subnet-1a2b3c4d' ]
+    vpc_zone_identifier: ['subnet-abcd1234', 'subnet-1a2b3c4d']
     tags:
       - environment: production
         propagate_at_launch: false
 
 # Basic Configuration with Launch Template using mixed instance policy
 
-- amazon.aws.autoscaling_group:
-    name: special
-    load_balancers: [ 'lb1', 'lb2' ]
-    availability_zones: [ 'eu-west-1a', 'eu-west-1b' ]
+- name: Example autoscaling group creation with a mixed instance policy
+  amazon.aws.autoscaling_group:
+    name: example_with_policy
+    load_balancers: ['lb1', 'lb2']
+    availability_zones: ['eu-west-1a', 'eu-west-1b']
     launch_template:
-        version: '1'
-        launch_template_name: 'lt-example'
-        launch_template_id: 'lt-123456'
+      version: '1'
+      launch_template_name: 'lt-example'
+      launch_template_id: 'lt-123456'
     mixed_instances_policy:
-        instance_types:
-            - t3a.large
-            - t3.large
-            - t2.large
-        instances_distribution:
-            on_demand_percentage_above_base_capacity: 0
-            spot_allocation_strategy: capacity-optimized
+      instance_types:
+        - t3a.large
+        - t3.large
+        - t2.large
+      instances_distribution:
+        on_demand_percentage_above_base_capacity: 0
+        spot_allocation_strategy: capacity-optimized
     min_size: 1
     max_size: 10
     desired_capacity: 5
-    vpc_zone_identifier: [ 'subnet-abcd1234', 'subnet-1a2b3c4d' ]
+    vpc_zone_identifier: ['subnet-abcd1234', 'subnet-1a2b3c4d']
     tags:
       - environment: production
         propagate_at_launch: false
@@ -664,29 +690,11 @@ from ansible.module_utils.common.dict_transformations import camel_dict_to_snake
 from ansible.module_utils.common.dict_transformations import snake_dict_to_camel_dict
 
 from ansible_collections.amazon.aws.plugins.module_utils.botocore import is_boto3_error_code
+from ansible_collections.amazon.aws.plugins.module_utils.elb_utils import describe_target_groups
 from ansible_collections.amazon.aws.plugins.module_utils.modules import AnsibleAWSModule
 from ansible_collections.amazon.aws.plugins.module_utils.retries import AWSRetry
 from ansible_collections.amazon.aws.plugins.module_utils.transformation import scrub_none_parameters
 
-ASG_ATTRIBUTES = (
-    "AvailabilityZones",
-    "DefaultCooldown",
-    "DesiredCapacity",
-    "HealthCheckGracePeriod",
-    "HealthCheckType",
-    "LaunchConfigurationName",
-    "LoadBalancerNames",
-    "MaxInstanceLifetime",
-    "MaxSize",
-    "MinSize",
-    "AutoScalingGroupName",
-    "PlacementGroup",
-    "TerminationPolicies",
-    "VPCZoneIdentifier",
-)
-
-INSTANCE_ATTRIBUTES = ("instance_id", "health_status", "lifecycle_state", "launch_config_name")
-
 backoff_params = dict(retries=10, delay=3, backoff=1.5)
 
 
@@ -900,7 +908,6 @@ def get_properties(autoscaling_group):
 
     if properties["target_group_arns"]:
         elbv2_connection = module.client("elbv2")
-        tg_paginator = elbv2_connection.get_paginator("describe_target_groups")
         # Limit of 20 similar to https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeLoadBalancers.html
         tg_chunk_size = 20
         properties["target_group_names"] = []
@@ -909,8 +916,9 @@ def get_properties(autoscaling_group):
             for i in range(0, len(properties["target_group_arns"]), tg_chunk_size)
         ]  # fmt: skip
         for chunk in tg_chunks:
-            tg_result = tg_paginator.paginate(TargetGroupArns=chunk).build_full_result()
-            properties["target_group_names"].extend([tg["TargetGroupName"] for tg in tg_result["TargetGroups"]])
+            properties["target_group_names"].extend(
+                [tg["TargetGroupName"] for tg in describe_target_groups(elbv2_connection, TargetGroupArns=chunk)]
+            )
     else:
         properties["target_group_names"] = []
 
@@ -1109,7 +1117,7 @@ def wait_for_target_group(asg_connection, group_name):
 
 
 def suspend_processes(ec2_connection, as_group):
-    suspend_processes = set(module.params.get("suspend_processes"))
+    processes_to_suspend = set(module.params.get("suspend_processes"))
 
     try:
         suspended_processes = set([p["ProcessName"] for p in as_group["SuspendedProcesses"]])
@@ -1117,15 +1125,15 @@ def suspend_processes(ec2_connection, as_group):
         # New ASG being created, no suspended_processes defined yet
         suspended_processes = set()
 
-    if suspend_processes == suspended_processes:
+    if processes_to_suspend == suspended_processes:
         return False
 
-    resume_processes = list(suspended_processes - suspend_processes)
+    resume_processes = list(suspended_processes - processes_to_suspend)
     if resume_processes:
         resume_asg_processes(ec2_connection, module.params.get("name"), resume_processes)
 
-    if suspend_processes:
-        suspend_asg_processes(ec2_connection, module.params.get("name"), list(suspend_processes))
+    if processes_to_suspend:
+        suspend_asg_processes(ec2_connection, module.params.get("name"), list(processes_to_suspend))
 
     return True
 
@@ -1363,7 +1371,7 @@ def create_autoscaling_group(connection):
                 changed = True
                 try:
                     attach_lb_target_groups(connection, group_name, list(tgs_to_attach))
-                except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
+                except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError):
                     module.fail_json(msg=f"Failed to attach load balancer target groups {tgs_to_attach}")
 
         # check for attributes that aren't required for updating an existing ASG
@@ -1494,9 +1502,9 @@ def delete_autoscaling_group(connection):
     return False
 
 
-def get_chunks(l, n):
-    for i in range(0, len(l), n):
-        yield l[i:i + n]  # fmt: skip
+def get_chunks(objects, chunk_size):
+    for i in range(0, len(objects), chunk_size):
+        yield objects[i:i + chunk_size]  # fmt: skip
 
 
 def update_size(connection, group, max_size, min_size, dc):
@@ -1675,15 +1683,15 @@ def get_instances_by_launch_config(props, lc_check, initial_instances):
                 old_instances.append(i)
 
     else:
-        module.debug(f"Comparing initial instances with current: {*initial_instances,}")
+        module.debug(f"Comparing initial instances with current: {(*initial_instances,)}")
         for i in props["instances"]:
             if i not in initial_instances:
                 new_instances.append(i)
             else:
                 old_instances.append(i)
 
-    module.debug(f"New instances: {len(new_instances)}, {*new_instances,}")
-    module.debug(f"Old instances: {len(old_instances)}, {*old_instances,}")
+    module.debug(f"New instances: {len(new_instances)}, {(*new_instances,)}")
+    module.debug(f"Old instances: {len(old_instances)}, {(*old_instances,)}")
 
     return new_instances, old_instances
 
@@ -1702,15 +1710,15 @@ def get_instances_by_launch_template(props, lt_check, initial_instances):
             else:
                 old_instances.append(i)
     else:
-        module.debug(f"Comparing initial instances with current: {*initial_instances,}")
+        module.debug(f"Comparing initial instances with current: {(*initial_instances,)}")
         for i in props["instances"]:
             if i not in initial_instances:
                 new_instances.append(i)
             else:
                 old_instances.append(i)
 
-    module.debug(f"New instances: {len(new_instances)}, {*new_instances,}")
-    module.debug(f"Old instances: {len(old_instances)}, {*old_instances,}")
+    module.debug(f"New instances: {len(new_instances)}, {(*new_instances,)}")
+    module.debug(f"Old instances: {len(old_instances)}, {(*old_instances,)}")
 
     return new_instances, old_instances
 
@@ -1775,9 +1783,9 @@ def terminate_batch(connection, replace_instances, initial_instances, leftovers=
     instances_to_terminate = list_purgeable_instances(props, lc_check, lt_check, replace_instances, initial_instances)
 
     module.debug(f"new instances needed: {num_new_inst_needed}")
-    module.debug(f"new instances: {*new_instances,}")
-    module.debug(f"old instances: {*old_instances,}")
-    module.debug(f"batch instances: {*instances_to_terminate,}")
+    module.debug(f"new instances: {(*new_instances,)}")
+    module.debug(f"old instances: {(*old_instances,)}")
+    module.debug(f"batch instances: {(*instances_to_terminate,)}")
 
     if num_new_inst_needed == 0:
         decrement_capacity = True
@@ -1868,7 +1876,7 @@ def asg_exists(connection):
 
 def main():
     argument_spec = dict(
-        name=dict(required=True, type="str"),
+        name=dict(required=True, type="str", aliases=["group_name"]),
         load_balancers=dict(type="list", elements="str"),
         target_group_arns=dict(type="list", elements="str"),
         availability_zones=dict(type="list", elements="str"),
@@ -1907,13 +1915,50 @@ def main():
         placement_group=dict(type="str"),
         desired_capacity=dict(type="int"),
         vpc_zone_identifier=dict(type="list", elements="str"),
-        replace_batch_size=dict(type="int", default=1),
-        replace_all_instances=dict(type="bool", default=False),
-        replace_instances=dict(type="list", default=[], elements="str"),
-        detach_instances=dict(type="list", default=[], elements="str"),
-        decrement_desired_capacity=dict(type="bool", default=False),
-        lc_check=dict(type="bool", default=True),
-        lt_check=dict(type="bool", default=True),
+        replace_batch_size=dict(
+            removed_in_version="14.0.0",
+            removed_from_collection="amazon.aws",
+            type="int",
+            default=1,
+        ),
+        replace_all_instances=dict(
+            removed_in_version="14.0.0",
+            removed_from_collection="amazon.aws",
+            type="bool",
+            default=False,
+        ),
+        replace_instances=dict(
+            removed_in_version="14.0.0",
+            removed_from_collection="amazon.aws",
+            type="list",
+            default=[],
+            elements="str",
+        ),
+        detach_instances=dict(
+            removed_in_version="14.0.0",
+            removed_from_collection="amazon.aws",
+            type="list",
+            default=[],
+            elements="str",
+        ),
+        decrement_desired_capacity=dict(
+            removed_in_version="14.0.0",
+            removed_from_collection="amazon.aws",
+            type="bool",
+            default=False,
+        ),
+        lc_check=dict(
+            removed_in_version="14.0.0",
+            removed_from_collection="amazon.aws",
+            type="bool",
+            default=True,
+        ),
+        lt_check=dict(
+            removed_in_version="14.0.0",
+            removed_from_collection="amazon.aws",
+            type="bool",
+            default=True,
+        ),
         wait_timeout=dict(type="int", default=300),
         state=dict(default="present", choices=["present", "absent"]),
         tags=dict(type="list", default=[], elements="dict"),
