@@ -10,7 +10,7 @@ module: ec2_instance_info
 version_added: 1.0.0
 short_description: Gather information about ec2 instances in AWS
 description:
-    - Gather information about ec2 instances in AWS
+    - Gather information about EC2 instances in AWS.
 author:
   - Michael Schuett (@michaeljs1990)
   - Rob White (@wimnat)
@@ -32,7 +32,7 @@ options:
     type: dict
   minimum_uptime:
     description:
-      - Minimum running uptime in minutes of instances.  For example if I(uptime) is C(60) return all instances that have run more than 60 minutes.
+      - Minimum running uptime in minutes of instances.  For example if O(uptime) is V(60) return all instances that have run more than 60 minutes.
     required: false
     aliases: ['uptime']
     type: int
@@ -91,7 +91,7 @@ EXAMPLES = r"""
 - name: Gather information about any instance in states "shutting-down", "stopping", "stopped"
   amazon.aws.ec2_instance_info:
     filters:
-      instance-state-name: [ "shutting-down", "stopping", "stopped" ]
+      instance-state-name: ["shutting-down", "stopping", "stopped"]
 
 - name: Gather information about any instance with Name beginning with RHEL and an uptime of at least 60 minutes
   amazon.aws.ec2_instance_info:
@@ -99,7 +99,7 @@ EXAMPLES = r"""
     uptime: 60
     filters:
       "tag:Name": "RHEL-*"
-      instance-state-name: [ "running"]
+      instance-state-name: ["running"]
   register: ec2_node_info
 
 - name: Gather information about a particular instance using ID and include kernel attribute
@@ -107,7 +107,7 @@ EXAMPLES = r"""
     instance_ids:
       - i-12345678
     include_attributes:
-        - kernel
+      - kernel
 """
 
 RETURN = r"""
@@ -161,6 +161,14 @@ instances:
                             returned: always
                             type: str
                             sample: vol-12345678
+        capacity_reservation_specification:
+            description: Information about the Capacity Reservation targeting option.
+            type: complex
+            contains:
+                capacity_reservation_preference:
+                    description: Describes the Capacity Reservation preferences.
+                    type: str
+                    sample: open
         cpu_options:
             description: The CPU options set for the instance.
             returned: always
@@ -181,11 +189,38 @@ instances:
             returned: always
             type: str
             sample: mytoken
+        current_instance_boot_mode:
+            description: The boot mode that is used to boot the instance at launch or start.
+            type: str
+            sample: legacy-bios
         ebs_optimized:
             description: Indicates whether the instance is optimized for EBS I/O.
             returned: always
             type: bool
             sample: false
+        ena_support:
+            description: Specifies whether enhanced networking with ENA is enabled.
+            returned: always
+            type: bool
+            sample: true
+        enclave_options:
+            description: Indicates whether the instance is enabled for Amazon Web Services Nitro Enclaves.
+            type: dict
+            contains:
+                enabled:
+                    description: If this parameter is set to true, the instance is enabled for Amazon Web Services Nitro Enclaves.
+                    returned: always
+                    type: bool
+                    sample: false
+        hibernation_options:
+            description: Indicates whether the instance is enabled for hibernation.
+            type: dict
+            contains:
+                configured:
+                    description: If true, your instance is enabled for hibernation; otherwise, it is not enabled for hibernation.
+                    returned: always
+                    type: bool
+                    sample: false
         hypervisor:
             description: The hypervisor type of the instance.
             returned: always
@@ -193,7 +228,6 @@ instances:
             sample: xen
         iam_instance_profile:
             description: The IAM instance profile associated with the instance, if applicable.
-            returned: always
             type: complex
             contains:
                 arn:
@@ -231,6 +265,44 @@ instances:
             returned: always
             type: str
             sample: "2017-03-23T22:51:24+00:00"
+        maintenance_options:
+            description: Provides information on the recovery and maintenance options of your instance.
+            returned: always
+            type: dict
+            contains:
+                auto_recovery:
+                    description: Provides information on the current automatic recovery behavior of your instance.
+                    type: str
+                    sample: default
+        metadata_options:
+            description: The metadata options for the instance.
+            returned: always
+            type: complex
+            contains:
+                http_endpoint:
+                    description: Indicates whether the HTTP metadata endpoint on your instances is enabled or disabled.
+                    type: str
+                    sample: enabled
+                http_protocol_ipv6:
+                    description: Indicates whether the IPv6 endpoint for the instance metadata service is enabled or disabled.
+                    type: str
+                    sample: disabled
+                http_put_response_hop_limit:
+                    description: The maximum number of hops that the metadata token can travel.
+                    type: int
+                    sample: 1
+                http_tokens:
+                    description: Indicates whether IMDSv2 is required.
+                    type: str
+                    sample: optional
+                instance_metadata_tags:
+                    description: Indicates whether access to instance tags from the instance metadata is enabled or disabled.
+                    type: str
+                    sample: disabled
+                state:
+                    description: The state of the metadata option changes.
+                    type: str
+                    sample: applied
         monitoring:
             description: The monitoring for the instance.
             returned: always
@@ -291,6 +363,11 @@ instances:
                             returned: always
                             type: int
                             sample: 0
+                        network_card_index:
+                            description: The index of the network card.
+                            returned: always
+                            type: int
+                            sample: 0
                         status:
                             description: The attachment state.
                             returned: always
@@ -317,6 +394,11 @@ instances:
                             returned: always
                             type: str
                             sample: mygroup
+                interface_type:
+                    description: The type of network interface.
+                    returned: always
+                    type: str
+                    sample: interface
                 ipv6_addresses:
                     description: One or more IPv6 addresses associated with the network interface.
                     returned: always
@@ -343,6 +425,11 @@ instances:
                     returned: always
                     type: str
                     sample: 01234567890
+                private_dns_name:
+                    description: The private DNS hostname name assigned to the instance.
+                    type: str
+                    returned: always
+                    sample: ip-10-1-0-156.ec2.internal
                 private_ip_address:
                     description: The IPv4 address of the network interface within the subnet.
                     returned: always
@@ -356,7 +443,6 @@ instances:
                     contains:
                         association:
                             description: The association information for an Elastic IP address (IPv4) associated with the network interface.
-                            returned: always
                             type: complex
                             contains:
                                 ip_owner_id:
@@ -379,6 +465,11 @@ instances:
                             returned: always
                             type: bool
                             sample: true
+                        private_dns_name:
+                            description: The private DNS hostname name assigned to the instance.
+                            type: str
+                            returned: always
+                            sample: ip-10-1-0-156.ec2.internal
                         private_ip_address:
                             description: The private IPv4 address of the network interface.
                             returned: always
@@ -424,11 +515,32 @@ instances:
                     returned: always
                     type: str
                     sample: default
+        platform_details:
+            description: The platform details value for the instance.
+            returned: always
+            type: str
+            sample: Linux/UNIX
         private_dns_name:
             description: The private DNS name.
             returned: always
             type: str
             sample: ip-10-0-0-1.ap-southeast-2.compute.internal
+        private_dns_name_options:
+            description: The options for the instance hostname.
+            type: dict
+            contains:
+                enable_resource_name_dns_a_record:
+                    description: Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
+                    type: bool
+                    sample: false
+                enable_resource_name_dns_aaaa_record:
+                    description: Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.
+                    type: bool
+                    sample: false
+                hostname_type:
+                    description: The type of hostname to assign to an instance.
+                    type: str
+                    sample: ip-name
         private_ip_address:
             description: The IPv4 address of the network interface within the subnet.
             returned: always
@@ -533,7 +645,7 @@ instances:
             sample: vpc-0011223344
         attributes:
             description: The details of the instance attribute specified on input.
-            returned: when include_attribute is specified
+            returned: when O(include_attributes) is specified
             type: dict
             sample:
                 {
@@ -548,51 +660,42 @@ instances:
 """
 
 import datetime
-
-try:
-    import botocore
-except ImportError:
-    pass  # caught by AnsibleAWSModule
+from typing import Any
+from typing import Dict
+from typing import List
 
 from ansible.module_utils.common.dict_transformations import camel_dict_to_snake_dict
 
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import AnsibleEC2Error
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import describe_instance_attribute
+from ansible_collections.amazon.aws.plugins.module_utils.ec2 import describe_instances
 from ansible_collections.amazon.aws.plugins.module_utils.modules import AnsibleAWSModule
-from ansible_collections.amazon.aws.plugins.module_utils.retries import AWSRetry
 from ansible_collections.amazon.aws.plugins.module_utils.tagging import boto3_tag_list_to_ansible_dict
 from ansible_collections.amazon.aws.plugins.module_utils.transformation import ansible_dict_to_boto3_filter_list
 
 
-@AWSRetry.jittered_backoff()
-def _describe_instances(connection, **params):
-    paginator = connection.get_paginator("describe_instances")
-    return paginator.paginate(**params).build_full_result()
-
-
-def list_ec2_instances(connection, module):
+def list_ec2_instances(connection, module: AnsibleAWSModule) -> None:
     instance_ids = module.params.get("instance_ids")
     uptime = module.params.get("minimum_uptime")
     filters = ansible_dict_to_boto3_filter_list(module.params.get("filters"))
 
-    try:
-        reservations = _describe_instances(connection, InstanceIds=instance_ids, Filters=filters)
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
-        module.fail_json_aws(e, msg="Failed to list ec2 instances")
-
+    reservations = describe_instances(connection, InstanceIds=instance_ids, Filters=filters)
     instances = []
+    oldest_launch_time = None
 
     if uptime:
         timedelta = int(uptime) if uptime else 0
-        oldest_launch_time = datetime.datetime.utcnow() - datetime.timedelta(minutes=timedelta)
-        # Get instances from reservations
-        for reservation in reservations["Reservations"]:
-            instances += [
+        oldest_launch_time = datetime.datetime.now() - datetime.timedelta(minutes=timedelta)
+
+    # Get instances from reservations
+    for reservation in reservations:
+        instances.extend(
+            [
                 instance
                 for instance in reservation["Instances"]
-                if instance["LaunchTime"].replace(tzinfo=None) < oldest_launch_time
+                if oldest_launch_time is None or instance["LaunchTime"].replace(tzinfo=None) < oldest_launch_time
             ]
-    else:
-        for reservation in reservations["Reservations"]:
-            instances = instances + reservation["Instances"]
+        )
 
     # include instances attributes
     attributes = module.params.get("include_attributes")
@@ -610,10 +713,10 @@ def list_ec2_instances(connection, module):
     module.exit_json(instances=snaked_instances)
 
 
-def describe_instance_attributes(connection, instance_id, attributes):
+def describe_instance_attributes(connection, instance_id: str, attributes: List[str]) -> Dict[str, Any]:
     result = {}
     for attr in attributes:
-        response = connection.describe_instance_attribute(Attribute=attr, InstanceId=instance_id)
+        response = describe_instance_attribute(connection, instance_id=instance_id, attribute=attr)
         for key in response:
             if key not in ("InstanceId", "ResponseMetadata"):
                 result[key] = response[key]
@@ -651,12 +754,11 @@ def main():
         supports_check_mode=True,
     )
 
+    connection = module.client("ec2")
     try:
-        connection = module.client("ec2")
-    except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
-        module.fail_json_aws(e, msg="Failed to connect to AWS")
-
-    list_ec2_instances(connection, module)
+        list_ec2_instances(connection, module)
+    except AnsibleEC2Error as e:
+        module.fail_json_aws_error(e)
 
 
 if __name__ == "__main__":
