@@ -1,38 +1,51 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: global_credential_update
-short_description: Resource module for Global Credential Update
+short_description: Resource module for Global Credential
+  Update
 description:
-  - This module represents an alias of the module global_credential_update_v1
+  - Manage operation update of the resource Global Credential
+    Update.
+  - Update global credential for network devices in
+    sites.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
 options:
   globalCredentialId:
-    description: GlobalCredentialId path parameter. Global credential Uuid.
+    description: GlobalCredentialId path parameter.
+      Global credential Uuid.
     type: str
   siteUuids:
-    description: List of siteUuids where credential is to be updated.
+    description: List of siteUuids where credential
+      is to be updated.
     elements: str
     type: list
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Discovery UpdateGlobalCredentialsV1
-    description: Complete reference of the UpdateGlobalCredentialsV1 API.
+  - name: Cisco DNA Center documentation for Discovery
+      UpdateGlobalCredentials
+    description: Complete reference of the UpdateGlobalCredentials
+      API.
     link: https://developer.cisco.com/docs/dna-center/#!update-global-credentials
 notes:
-  - SDK Method used are discovery.Discovery.update_global_credentials_v1,
-  - Paths used are put /dna/intent/api/v1/global-credential/{globalCredentialId},
-  - It should be noted that this module is an alias of global_credential_update_v1
+  - SDK Method used are
+    discovery.Discovery.update_global_credentials,
+  - Paths used are
+    put /dna/intent/api/v1/global-credential/{globalCredentialId},
 """
+
 EXAMPLES = r"""
+---
 - name: Update by id
   cisco.dnac.global_credential_update:
     dnac_host: "{{dnac_host}}"
