@@ -31,6 +31,7 @@
 # Contributors: David Soper, Chris Gascoigne, John McDonough
 
 from __future__ import (absolute_import, division, print_function)
+
 __metaclass__ = type
 
 from base64 import b64encode
@@ -38,6 +39,8 @@ from email.utils import formatdate
 import re
 import json
 import hashlib
+from typing import Optional
+
 from ansible.module_utils.six import iteritems
 from ansible.module_utils.six.moves.urllib.parse import urlparse, urlencode
 from ansible.module_utils.urls import fetch_url
@@ -45,14 +48,16 @@ from ansible.module_utils.basic import env_fallback
 
 try:
     from cryptography.hazmat.primitives import serialization, hashes
-    from cryptography.hazmat.primitives.asymmetric import padding, ec
+    from cryptography.hazmat.primitives.asymmetric import padding, ec, rsa
     from cryptography.hazmat.backends import default_backend
+
     HAS_CRYPTOGRAPHY = True
 except ImportError:
     HAS_CRYPTOGRAPHY = False
 
 intersight_argument_spec = dict(
-    api_private_key=dict(fallback=(env_fallback, ['INTERSIGHT_API_PRIVATE_KEY']), type='path', required=True, no_log=True),
+    api_private_key=dict(fallback=(env_fallback, ['INTERSIGHT_API_PRIVATE_KEY']), type='path', required=True,
+                         no_log=True),
     api_uri=dict(fallback=(env_fallback, ['INTERSIGHT_API_URI']), type='str', default='https://intersight.com/api/v1'),
     api_key_id=dict(fallback=(env_fallback, ['INTERSIGHT_API_KEY_ID']), type='str', required=True),
     validate_certs=dict(type='bool', default=True),
@@ -132,12 +137,31 @@ def compare_values(expected, actual):
         # loop complete with all items matching
         return True
     except (AttributeError, TypeError):
+        # Handle Intersight object references: when expected is a MOID string and actual is an object reference
+        if (isinstance(expected, str) and isinstance(actual, dict) and 'Moid' in actual and actual.get('ClassId') == 'mo.MoRef'):
+            # Compare the MOID string against the Moid field in the object reference
+            if actual['Moid'] == expected:
+                return True
+        # Handle case where expected is a string and actual is an object reference
+        elif (isinstance(expected, str) and isinstance(actual, dict) and
+              'Name' in actual and actual.get('ObjectType') == 'organization.Organization'):
+            if actual['Name'] == expected:
+                return True
         # if expected and actual != expected:
         if actual != expected:
             return False
         return True
 
 
+# This will fix the format of a v3 secret key, if needed.
+# Some v3 keys PEM files are incorrectly formatted with
+# "BEGIN EC PRIVATE KEY" instead of "BEGIN PRIVATE KEY"
+def _fix_v3_key_format(secret_key: bytes):
+    return secret_key.replace(
+        b"-----BEGIN EC PRIVATE KEY-----", b"-----BEGIN PRIVATE KEY-----"
+    ).replace(b"-----END EC PRIVATE KEY-----", b"-----END PRIVATE KEY-----")
+
+
 class IntersightModule():
 
     def __init__(self, module):
@@ -154,6 +178,7 @@ class IntersightModule():
             self.private_key = self.module.params['api_private_key']
         self.digest_algorithm = ''
         self.response_list = []
+        self.update_method = ''
 
     def get_sig_b64encode(self, data):
         """
@@ -162,21 +187,19 @@ class IntersightModule():
         :param digest: string to be signed & hashed
         :return: instance of digest object
         """
-        # Python SDK code: Verify PEM Pre-Encapsulation Boundary
-        r = re.compile(r"\s*-----BEGIN (.*)-----\s+")
-        m = r.match(self.private_key)
-        if not m:
-            raise ValueError("Not a valid PEM pre boundary")
-        pem_header = m.group(1)
-        key = serialization.load_pem_private_key(self.private_key.encode(), None, default_backend())
-        if pem_header == 'RSA PRIVATE KEY':
+        try:
+            key = serialization.load_pem_private_key(self.private_key.encode(), None, default_backend())
+        except (ValueError):
+            key = serialization.load_pem_private_key(_fix_v3_key_format(self.private_key.encode()), None, default_backend())
+
+        if isinstance(key, rsa.RSAPrivateKey):
             sign = key.sign(data.encode(), padding.PKCS1v15(), hashes.SHA256())
             self.digest_algorithm = 'rsa-sha256'
-        elif pem_header == 'EC PRIVATE KEY':
+        elif isinstance(key, ec.EllipticCurvePrivateKey):
             sign = key.sign(data.encode(), ec.ECDSA(hashes.SHA256()))
             self.digest_algorithm = 'hs2019'
         else:
-            raise Exception("Unsupported key: {0}".format(pem_header))
+            raise Exception("Unsupported key: {0}".format(type(key).__name__))
 
         return b64encode(sign)
 
@@ -203,33 +226,6 @@ class IntersightModule():
 
         return auth_str
 
-    def get_moid_by_name(self, resource_path, target_name):
-        """
-        Retrieve an Intersight object moid by name
-
-        :param resource_path: intersight resource path e.g. '/ntp/Policies'
-        :param target_name: intersight object name
-        :return: json http response object
-        """
-        query_params = {
-            "$filter": "Name eq '{0}'".format(target_name)
-        }
-
-        options = {
-            "http_method": "GET",
-            "resource_path": resource_path,
-            "query_params": query_params
-        }
-
-        get_moid = self.intersight_call(**options)
-
-        if get_moid.json()['Results'] is not None:
-            located_moid = get_moid.json()['Results'][0]['Moid']
-        else:
-            raise KeyError('Intersight object with name "{0}" not found!'.format(target_name))
-
-        return located_moid
-
     def call_api(self, **options):
         """
         Call the Intersight API and check for success status
@@ -242,7 +238,7 @@ class IntersightModule():
             if not re.match(r'2..', str(info['status'])):
                 raise RuntimeError(info['status'], info['msg'], info['body'])
         except Exception as e:
-            self.module.fail_json(msg="API error: %s " % str(e))
+            self.module.fail_json(msg="Code exception: %s " % str(e))
 
         response_data = response.read()
         if len(response_data) > 0:
@@ -285,6 +281,9 @@ class IntersightModule():
         if (moid is not None and len(moid.encode('utf-8')) != 24):
             raise ValueError('Invalid *moid* value!')
 
+        if (method != 'PATCH' and self.update_method == 'json-patch'):
+            raise ValueError('json-patch is only supported with PATCH on existing resource')
+
         # Check for query_params, encode, and concatenate onto URL
         if query_params:
             query_path = "?" + urlencode(query_params)
@@ -331,16 +330,21 @@ class IntersightModule():
         auth_header = self.get_auth_header(auth_header, b64_signed_msg)
 
         # Generate the HTTP requests header
+        if self.update_method == 'json-patch':
+            content_type = 'application/json-patch+json'
+        else:
+            content_type = 'application/json'
         request_header = {
             'Accept': 'application/json',
-            'Content-Type': 'application/json',
+            'Content-Type': content_type,
             'Host': '{0}'.format(target_host),
             'Date': '{0}'.format(cdate),
             'Digest': 'SHA-256={0}'.format(b64_body_digest.decode('ascii')),
             'Authorization': '{0}'.format(auth_header),
         }
 
-        response, info = fetch_url(self.module, target_url, data=bodyString, headers=request_header, method=method, use_proxy=self.module.params['use_proxy'])
+        response, info = fetch_url(self.module, target_url, data=bodyString, headers=request_header, method=method,
+                                   use_proxy=self.module.params['use_proxy'])
 
         return response, info
 
@@ -363,10 +367,17 @@ class IntersightModule():
                     self.module.warn('More than 1 resource found, returning the 1st one')
                 # return the 1st list element
                 self.result['api_response'] = response['Results'][0]
-        self.result['count'] = response.get('Count')
+        else:
+            # Clear api_response when no results found to prevent returning stale data
+            if return_list:
+                self.result['api_response'] = []
+            else:
+                self.result['api_response'] = {}
+        self.result['count'] = response.get('Count', 0)
         self.result['trace_id'] = response.get('trace_id')
 
     def configure_resource(self, moid, resource_path, body, query_params, update_method=''):
+        self.update_method = update_method
         if not self.module.check_mode:
             if moid and update_method != 'post':
                 # update the resource - user has to specify all the props they want updated
@@ -381,6 +392,10 @@ class IntersightModule():
                     # return the 1st element in the results list
                     self.result['api_response'] = response_dict['Results'][0]
                     self.result['trace_id'] = response_dict.get('trace_id')
+                elif response_dict and 'Moid' in response_dict:
+                    # PATCH returned the updated object directly (not in Results array)
+                    self.result['api_response'] = response_dict
+                    self.result['trace_id'] = response_dict.get('trace_id')
             else:
                 # create the resource
                 options = {
@@ -414,24 +429,15 @@ class IntersightModule():
             self.result['trace_id'] = resp.get('trace_id')
         self.result['changed'] = True
 
-    def configure_policy_or_profile(self, resource_path):
+    def configure_policy_or_profile(self, resource_path, filter_key=None, filter_value=None):
         # Configure (create, update, or delete) the policy or profile
-        organization_moid = None
-        # GET Organization Moid
-        self.get_resource(
-            resource_path='/organization/Organizations',
-            query_params={
-                '$filter': "Name eq '" + self.module.params['organization'] + "'",
-                '$select': 'Moid',
-            },
-        )
-        if self.result['api_response'].get('Moid'):
-            # resource exists and moid was returned
-            organization_moid = self.result['api_response']['Moid']
+        organization_moid = self.get_moid_by_name(resource_path='/organization/Organizations', resource_name=self.module.params['organization'])
 
         self.result['api_response'] = {}
         # Get the current state of the resource
         filter_str = "Name eq '" + self.module.params['name'] + "'"
+        if filter_value and filter_key:
+            filter_str += " and " + filter_key + " eq '" + filter_value + "'"
         filter_str += "and Organization.Moid eq '" + organization_moid + "'"
         self.get_resource(
             resource_path=resource_path,
@@ -476,3 +482,97 @@ class IntersightModule():
                 moid = self.result['api_response']['Moid']
 
         return moid
+
+    def configure_secondary_resource(self, resource_path, resource_name=None, state='present', custom_filter=None):
+        # Configure (create, update, or delete) resources
+        # This method is used to configure secondery resources that are part of a policy or profile (e.g. VLANs)
+
+        self.result['api_response'] = {}
+        # Get the current state of the resource
+        if custom_filter:
+            filter_str = custom_filter
+        elif resource_name:
+            filter_str = "Name eq '" + resource_name + "'"
+        else:
+            raise ValueError("Either resource_name or custom_filter must be provided")
+        self.get_resource(
+            resource_path=resource_path,
+            query_params={
+                '$filter': filter_str
+            }
+        )
+
+        moid = None
+        resource_values_match = False
+        if self.result['api_response'].get('Moid'):
+            # resource exists and moid was returned
+            moid = self.result['api_response']['Moid']
+            if state == 'present':
+                resource_values_match = compare_values(self.api_body, self.result['api_response'])
+            else:  # state == 'absent'
+                self.delete_resource(
+                    moid=moid,
+                    resource_path=resource_path,
+                )
+                moid = None
+
+        if state == 'present' and not resource_values_match:
+            self.configure_resource(
+                moid=moid,
+                resource_path=resource_path,
+                body=self.api_body,
+                query_params={
+                    '$filter': filter_str
+                }
+            )
+            if self.result['api_response'].get('Moid'):
+                # resource exists and moid was returned
+                moid = self.result['api_response']['Moid']
+
+        return moid
+
+    def get_moid_by_name(self, resource_path, resource_name) -> Optional[str]:
+        '''
+        Get the moid of the resource by the value of the resource
+        '''
+        organization_moid = None
+        # GET Moid of the resource
+        self.get_resource(
+            resource_path=resource_path,
+            query_params={
+                '$filter': "Name eq '" + resource_name + "'",
+                '$select': 'Moid',
+            },
+        )
+        if self.result['api_response'].get('Moid'):
+            # resource exists and moid was returned
+            return self.result['api_response']['Moid']
+        return None
+
+    def set_query_params(self, filter_key=None, filter_value=None) -> dict:
+        filter_conditions = []
+        name_to_filter = self.module.params.get('name')
+        org_to_filter = self.module.params.get('organization')
+        if name_to_filter:
+            filter_conditions.append(f"Name eq '{name_to_filter}'")
+
+        if org_to_filter:
+            org_moid = self.get_moid_by_name(resource_path='/organization/Organizations', resource_name=org_to_filter)
+            filter_conditions.append(f"Organization.Moid eq '{org_moid}'")
+
+        if filter_value and filter_key:
+            filter_conditions.append(f"'{filter_key}' eq '{filter_value}'")
+
+        query_params = {}
+        if filter_conditions:
+            query_params["$filter"] = " and ".join(filter_conditions)
+        return query_params
+
+    def set_tags_and_description(self):
+        """
+        Generalize the pattern of setting tags and description in api_body if they are provided in module params.
+        """
+        if self.module.params.get('tags'):
+            self.api_body['Tags'] = self.module.params['tags']
+        if self.module.params.get('description'):
+            self.api_body['Description'] = self.module.params['description']
