@@ -694,7 +694,7 @@ class Condition(object):
             update["Updates"] = missing + extra
             func = getattr(self.client, "update_" + self.method_suffix)
             try:
-                result = run_func_with_change_token_backoff(self.client, self.module, update, func, wait=True)
+                run_func_with_change_token_backoff(self.client, self.module, update, func, wait=True)
             except (botocore.exceptions.ClientError, botocore.exceptions.BotoCoreError) as e:
                 self.module.fail_json_aws(e, msg="Could not update condition")
         return changed, self.get_condition_by_id(condition_set_id)
@@ -734,12 +734,18 @@ def main():
         target_string=dict(),  # Bytes
         size=dict(type="int"),
         ip_address=dict(),
-        regex_pattern=dict(),
+        regex_pattern=dict(
+            type="dict",
+            options=dict(
+                name=dict(),
+                regex_strings=dict(type="list", elements="str"),
+            ),
+        ),
     )
     argument_spec = dict(
         name=dict(required=True),
         type=dict(required=True, choices=["byte", "geo", "ip", "regex", "size", "sql", "xss"]),
-        filters=dict(type="list", elements="dict"),
+        filters=dict(type="list", elements="dict", options=filters_subspec),
         purge_filters=dict(type="bool", default=False),
         waf_regional=dict(type="bool", default=False),
         state=dict(default="present", choices=["present", "absent"]),
