@@ -6,12 +6,17 @@
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
+#
+# DEPRECATED
+#
+# This fragment is deprecated and will be removed in community.general 13.0.0
+#
+
 
 class ModuleDocFragment(object):
-    DOCUMENTATION = """
-    options:
-        name:
-            description: Use O(name) along with the other options to return only resources that match the given name
-                         exactly.
-            type: str
-    """
+    DOCUMENTATION = r"""
+options:
+  name:
+    description: Use O(name) along with the other options to return only resources that match the given name exactly.
+    type: str
+"""
