@@ -3,119 +3,122 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
-DOCUMENTATION = r'''
-    name: lxd
-    short_description: Returns Ansible inventory from lxd host
+DOCUMENTATION = r"""
+name: lxd
+short_description: Returns Ansible inventory from lxd host
+description:
+  - Get inventory from the lxd.
+  - Uses a YAML configuration file that ends with 'lxd.(yml|yaml)'.
+version_added: "3.0.0"
+author: "Frank Dornheim (@conloos)"
+requirements:
+  - ipaddress
+  - lxd >= 4.0
+options:
+  plugin:
+    description: Token that ensures this is a source file for the 'lxd' plugin.
+    type: string
+    required: true
+    choices: ['community.general.lxd']
+  url:
     description:
-        - Get inventory from the lxd.
-        - Uses a YAML configuration file that ends with 'lxd.(yml|yaml)'.
-    version_added: "3.0.0"
-    author: "Frank Dornheim (@conloos)"
-    requirements:
-        - ipaddress
-        - lxd >= 4.0
-    options:
-        plugin:
-            description: Token that ensures this is a source file for the 'lxd' plugin.
-            required: true
-            choices: [ 'community.general.lxd' ]
-        url:
-            description:
-            - The unix domain socket path or the https URL for the lxd server.
-            - Sockets in filesystem have to start with C(unix:).
-            - Mostly C(unix:/var/lib/lxd/unix.socket) or C(unix:/var/snap/lxd/common/lxd/unix.socket).
-            default: unix:/var/snap/lxd/common/lxd/unix.socket
-            type: str
-        client_key:
-            description:
-            - The client certificate key file path.
-            aliases: [ key_file ]
-            default: $HOME/.config/lxc/client.key
-            type: path
-        client_cert:
-            description:
-            - The client certificate file path.
-            aliases: [ cert_file ]
-            default: $HOME/.config/lxc/client.crt
-            type: path
-        server_cert:
-            description:
-            - The server certificate file path.
-            type: path
-            version_added: 8.0.0
-        server_check_hostname:
-            description:
-            - This option controls if the server's hostname is checked as part of the HTTPS connection verification.
-              This can be useful to disable, if for example, the server certificate provided (see O(server_cert) option)
-              does not cover a name matching the one used to communicate with the server. Such mismatch is common as LXD
-              generates self-signed server certificates by default.
-            type: bool
-            default: true
-            version_added: 8.0.0
-        trust_password:
-            description:
-            - The client trusted password.
-            - You need to set this password on the lxd server before
-                running this module using the following command
-                C(lxc config set core.trust_password <some random password>)
-                See U(https://documentation.ubuntu.com/lxd/en/latest/authentication/#adding-client-certificates-using-a-trust-password).
-            - If O(trust_password) is set, this module send a request for authentication before sending any requests.
-            type: str
-        state:
-            description: Filter the instance according to the current status.
-            type: str
-            default: none
-            choices: [ 'STOPPED', 'STARTING', 'RUNNING', 'none' ]
-        project:
-            description: Filter the instance according to the given project.
-            type: str
-            default: default
-            version_added: 6.2.0
-        type_filter:
-            description:
-            - Filter the instances by type V(virtual-machine), V(container) or V(both).
-            - The first version of the inventory only supported containers.
-            type: str
-            default: container
-            choices: [ 'virtual-machine', 'container', 'both' ]
-            version_added: 4.2.0
-        prefered_instance_network_interface:
-            description:
-            - If an instance has multiple network interfaces, select which one is the preferred as pattern.
-            - Combined with the first number that can be found e.g. 'eth' + 0.
-            - The option has been renamed from O(prefered_container_network_interface) to O(prefered_instance_network_interface)
-              in community.general 3.8.0. The old name still works as an alias.
-            type: str
-            default: eth
-            aliases:
-              - prefered_container_network_interface
-        prefered_instance_network_family:
-            description:
-            - If an instance has multiple network interfaces, which one is the preferred by family.
-            - Specify V(inet) for IPv4 and V(inet6) for IPv6.
-            type: str
-            default: inet
-            choices: [ 'inet', 'inet6' ]
-        groupby:
-            description:
-            - Create groups by the following keywords C(location), C(network_range), C(os), C(pattern), C(profile), C(release), C(type), C(vlanid).
-            - See example for syntax.
-            type: dict
-'''
+      - The unix domain socket path or the https URL for the lxd server.
+      - Sockets in filesystem have to start with C(unix:).
+      - Mostly C(unix:/var/lib/lxd/unix.socket) or C(unix:/var/snap/lxd/common/lxd/unix.socket).
+    type: string
+    default: unix:/var/snap/lxd/common/lxd/unix.socket
+  client_key:
+    description:
+      - The client certificate key file path.
+    aliases: [key_file]
+    default: $HOME/.config/lxc/client.key
+    type: path
+  client_cert:
+    description:
+      - The client certificate file path.
+    aliases: [cert_file]
+    default: $HOME/.config/lxc/client.crt
+    type: path
+  server_cert:
+    description:
+      - The server certificate file path.
+    type: path
+    version_added: 8.0.0
+  server_check_hostname:
+    description:
+      - This option controls if the server's hostname is checked as part of the HTTPS connection verification. This can be
+        useful to disable, if for example, the server certificate provided (see O(server_cert) option) does not cover a name
+        matching the one used to communicate with the server. Such mismatch is common as LXD generates self-signed server
+        certificates by default.
+    type: bool
+    default: true
+    version_added: 8.0.0
+  trust_password:
+    description:
+      - The client trusted password.
+      - You need to set this password on the lxd server before running this module using the following command C(lxc config
+        set core.trust_password <some random password>) See
+        U(https://documentation.ubuntu.com/lxd/en/latest/authentication/#adding-client-certificates-using-a-trust-password).
+      - If O(trust_password) is set, this module send a request for authentication before sending any requests.
+    type: str
+  state:
+    description: Filter the instance according to the current status.
+    type: str
+    default: none
+    choices: ['STOPPED', 'STARTING', 'RUNNING', 'none']
+  project:
+    description: Filter the instance according to the given project.
+    type: str
+    default: default
+    version_added: 6.2.0
+  type_filter:
+    description:
+      - Filter the instances by type V(virtual-machine), V(container) or V(both).
+      - The first version of the inventory only supported containers.
+    type: str
+    default: container
+    choices: ['virtual-machine', 'container', 'both']
+    version_added: 4.2.0
+  prefered_instance_network_interface:
+    description:
+      - If an instance has multiple network interfaces, select which one is the preferred as pattern.
+      - Combined with the first number that can be found, for example C(eth) + C(0).
+      - The option has been renamed from O(prefered_container_network_interface) to O(prefered_instance_network_interface)
+        in community.general 3.8.0. The old name still works as an alias.
+    type: str
+    default: eth
+    aliases:
+      - prefered_container_network_interface
+  prefered_instance_network_family:
+    description:
+      - If an instance has multiple network interfaces, which one is the preferred by family.
+      - Specify V(inet) for IPv4 and V(inet6) for IPv6.
+    type: str
+    default: inet
+    choices: ['inet', 'inet6']
+  groupby:
+    description:
+      - Create groups by the following keywords C(location), C(network_range), C(os), C(pattern), C(profile), C(release),
+        C(type), C(vlanid).
+      - See example for syntax.
+    type: dict
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
+---
 # simple lxd.yml
 plugin: community.general.lxd
 url: unix:/var/snap/lxd/common/lxd/unix.socket
 
+---
 # simple lxd.yml including filter
 plugin: community.general.lxd
 url: unix:/var/snap/lxd/common/lxd/unix.socket
 state: RUNNING
 
+---
 # simple lxd.yml including virtual machines and containers
 plugin: community.general.lxd
 url: unix:/var/snap/lxd/common/lxd/unix.socket
@@ -162,19 +165,20 @@ groupby:
   projectInternals:
     type: project
     attribute: internals
-'''
+"""
 
 import json
 import re
 import time
 import os
+from urllib.parse import urlencode
+
 from ansible.plugins.inventory import BaseInventoryPlugin
 from ansible.module_utils.common.text.converters import to_native, to_text
 from ansible.module_utils.common.dict_transformations import dict_merge
-from ansible.module_utils.six import raise_from
 from ansible.errors import AnsibleError, AnsibleParserError
-from ansible.module_utils.six.moves.urllib.parse import urlencode
 from ansible_collections.community.general.plugins.module_utils.lxd import LXDClient, LXDClientException
+from ansible_collections.community.general.plugins.plugin_utils.unsafe import make_unsafe
 
 try:
     import ipaddress
@@ -209,7 +213,7 @@ class InventoryModule(BaseInventoryPlugin):
             with open(path, 'r') as json_file:
                 return json.load(json_file)
         except (IOError, json.decoder.JSONDecodeError) as err:
-            raise AnsibleParserError('Could not load the test data from {0}: {1}'.format(to_native(path), to_native(err)))
+            raise AnsibleParserError(f'Could not load the test data from {to_native(path)}: {err}')
 
     def save_json_data(self, path, file_name=None):
         """save data as json
@@ -239,7 +243,7 @@ class InventoryModule(BaseInventoryPlugin):
             with open(os.path.abspath(os.path.join(cwd, *path)), 'w') as json_file:
                 json.dump(self.data, json_file)
         except IOError as err:
-            raise AnsibleParserError('Could not save data: {0}'.format(to_native(err)))
+            raise AnsibleParserError(f'Could not save data: {err}')
 
     def verify_file(self, path):
         """Check the config
@@ -279,7 +283,7 @@ class InventoryModule(BaseInventoryPlugin):
         if not isinstance(url, str):
             return False
         if not url.startswith(('unix:', 'https:')):
-            raise AnsibleError('URL is malformed: {0}'.format(to_native(url)))
+            raise AnsibleError(f'URL is malformed: {url}')
         return True
 
     def _connect_to_socket(self):
@@ -304,7 +308,7 @@ class InventoryModule(BaseInventoryPlugin):
                 return socket_connection
             except LXDClientException as err:
                 error_storage[url] = err
-        raise AnsibleError('No connection to the socket: {0}'.format(to_native(error_storage)))
+        raise AnsibleError(f'No connection to the socket: {error_storage}')
 
     def _get_networks(self):
         """Get Networknames
@@ -353,7 +357,7 @@ class InventoryModule(BaseInventoryPlugin):
         #      }
         url = '/1.0/instances'
         if self.project:
-            url = url + '?{0}'.format(urlencode(dict(project=self.project)))
+            url = f"{url}?{urlencode(dict(project=self.project))}"
 
         instances = self.socket.do('GET', url)
 
@@ -381,10 +385,10 @@ class InventoryModule(BaseInventoryPlugin):
         config = {}
         if isinstance(branch, (tuple, list)):
             config[name] = {branch[1]: self.socket.do(
-                'GET', '/1.0/{0}/{1}/{2}?{3}'.format(to_native(branch[0]), to_native(name), to_native(branch[1]), urlencode(dict(project=self.project))))}
+                'GET', f'/1.0/{to_native(branch[0])}/{to_native(name)}/{to_native(branch[1])}?{urlencode(dict(project=self.project))}')}
         else:
             config[name] = {branch: self.socket.do(
-                'GET', '/1.0/{0}/{1}?{2}'.format(to_native(branch), to_native(name), urlencode(dict(project=self.project))))}
+                'GET', f'/1.0/{to_native(branch)}/{to_native(name)}?{urlencode(dict(project=self.project))}')}
         return config
 
     def get_instance_data(self, names):
@@ -447,7 +451,7 @@ class InventoryModule(BaseInventoryPlugin):
             None
         Returns:
             dict(network_configuration): network config"""
-        instance_network_interfaces = self._get_data_entry('instances/{0}/state/metadata/network'.format(instance_name))
+        instance_network_interfaces = self._get_data_entry(f'instances/{instance_name}/state/metadata/network')
         network_configuration = None
         if instance_network_interfaces:
             network_configuration = {}
@@ -460,7 +464,7 @@ class InventoryModule(BaseInventoryPlugin):
                     address_set['family'] = address.get('family')
                     address_set['address'] = address.get('address')
                     address_set['netmask'] = address.get('netmask')
-                    address_set['combined'] = address.get('address') + '/' + address.get('netmask')
+                    address_set['combined'] = f"{address.get('address')}/{address.get('netmask')}"
                     network_configuration[interface_name].append(address_set)
         return network_configuration
 
@@ -470,14 +474,14 @@ class InventoryModule(BaseInventoryPlugin):
         Helper to get the preferred interface provide by neme pattern from 'prefered_instance_network_interface'.
 
         Args:
-            str(containe_name): name of instance
+            str(instance_name): name of instance
         Kwargs:
             None
         Raises:
             None
         Returns:
             str(prefered_interface): None or interface name"""
-        instance_network_interfaces = self._get_data_entry('inventory/{0}/network_interfaces'.format(instance_name))
+        instance_network_interfaces = self._get_data_entry(f'inventory/{instance_name}/network_interfaces')
         prefered_interface = None  # init
         if instance_network_interfaces:  # instance have network interfaces
             # generator if interfaces which start with the desired pattern
@@ -495,7 +499,7 @@ class InventoryModule(BaseInventoryPlugin):
         Helper to get the VLAN_ID from the instance
 
         Args:
-            str(containe_name): name of instance
+            str(instance_name): name of instance
         Kwargs:
             None
         Raises:
@@ -514,7 +518,7 @@ class InventoryModule(BaseInventoryPlugin):
         #          "network":"lxdbr0",
         #          "type":"nic"},
         vlan_ids = {}
-        devices = self._get_data_entry('instances/{0}/instances/metadata/expanded_devices'.format(to_native(instance_name)))
+        devices = self._get_data_entry(f'instances/{to_native(instance_name)}/instances/metadata/expanded_devices')
         for device in devices:
             if 'network' in devices[device]:
                 if devices[device]['network'] in network_vlans:
@@ -577,7 +581,7 @@ class InventoryModule(BaseInventoryPlugin):
             else:
                 path[instance_name][key] = value
         except KeyError as err:
-            raise AnsibleParserError("Unable to store Information: {0}".format(to_native(err)))
+            raise AnsibleParserError(f"Unable to store Information: {err}")
 
     def extract_information_from_instance_configs(self):
         """Process configuration information
@@ -598,24 +602,24 @@ class InventoryModule(BaseInventoryPlugin):
 
         for instance_name in self.data['instances']:
             self._set_data_entry(instance_name, 'os', self._get_data_entry(
-                'instances/{0}/instances/metadata/config/image.os'.format(instance_name)))
+                f'instances/{instance_name}/instances/metadata/config/image.os'))
             self._set_data_entry(instance_name, 'release', self._get_data_entry(
-                'instances/{0}/instances/metadata/config/image.release'.format(instance_name)))
+                f'instances/{instance_name}/instances/metadata/config/image.release'))
             self._set_data_entry(instance_name, 'version', self._get_data_entry(
-                'instances/{0}/instances/metadata/config/image.version'.format(instance_name)))
+                f'instances/{instance_name}/instances/metadata/config/image.version'))
             self._set_data_entry(instance_name, 'profile', self._get_data_entry(
-                'instances/{0}/instances/metadata/profiles'.format(instance_name)))
+                f'instances/{instance_name}/instances/metadata/profiles'))
             self._set_data_entry(instance_name, 'location', self._get_data_entry(
-                'instances/{0}/instances/metadata/location'.format(instance_name)))
+                f'instances/{instance_name}/instances/metadata/location'))
             self._set_data_entry(instance_name, 'state', self._get_data_entry(
-                'instances/{0}/instances/metadata/config/volatile.last_state.power'.format(instance_name)))
+                f'instances/{instance_name}/instances/metadata/config/volatile.last_state.power'))
             self._set_data_entry(instance_name, 'type', self._get_data_entry(
-                'instances/{0}/instances/metadata/type'.format(instance_name)))
+                f'instances/{instance_name}/instances/metadata/type'))
             self._set_data_entry(instance_name, 'network_interfaces', self.extract_network_information_from_instance_config(instance_name))
             self._set_data_entry(instance_name, 'preferred_interface', self.get_prefered_instance_network_interface(instance_name))
             self._set_data_entry(instance_name, 'vlan_ids', self.get_instance_vlans(instance_name))
             self._set_data_entry(instance_name, 'project', self._get_data_entry(
-                'instances/{0}/instances/metadata/project'.format(instance_name)))
+                f'instances/{instance_name}/instances/metadata/project'))
 
     def build_inventory_network(self, instance_name):
         """Add the network interfaces of the instance to the inventory
@@ -649,18 +653,18 @@ class InventoryModule(BaseInventoryPlugin):
                 None
             Returns:
                 dict(interface_name: ip)"""
-            prefered_interface = self._get_data_entry('inventory/{0}/preferred_interface'.format(instance_name))  # name or None
+            prefered_interface = self._get_data_entry(f'inventory/{instance_name}/preferred_interface')  # name or None
             prefered_instance_network_family = self.prefered_instance_network_family
 
             ip_address = ''
             if prefered_interface:
-                interface = self._get_data_entry('inventory/{0}/network_interfaces/{1}'.format(instance_name, prefered_interface))
+                interface = self._get_data_entry(f'inventory/{instance_name}/network_interfaces/{prefered_interface}')
                 for config in interface:
                     if config['family'] == prefered_instance_network_family:
                         ip_address = config['address']
                         break
             else:
-                interfaces = self._get_data_entry('inventory/{0}/network_interfaces'.format(instance_name))
+                interfaces = self._get_data_entry(f'inventory/{instance_name}/network_interfaces')
                 for interface in interfaces.values():
                     for config in interface:
                         if config['family'] == prefered_instance_network_family:
@@ -668,9 +672,9 @@ class InventoryModule(BaseInventoryPlugin):
                             break
             return ip_address
 
-        if self._get_data_entry('inventory/{0}/network_interfaces'.format(instance_name)):  # instance have network interfaces
+        if self._get_data_entry(f'inventory/{instance_name}/network_interfaces'):  # instance have network interfaces
             self.inventory.set_variable(instance_name, 'ansible_connection', 'ssh')
-            self.inventory.set_variable(instance_name, 'ansible_host', interface_selection(instance_name))
+            self.inventory.set_variable(instance_name, 'ansible_host', make_unsafe(interface_selection(instance_name)))
         else:
             self.inventory.set_variable(instance_name, 'ansible_connection', 'local')
 
@@ -689,38 +693,46 @@ class InventoryModule(BaseInventoryPlugin):
         Returns:
             None"""
         for instance_name in self.data['inventory']:
-            instance_state = str(self._get_data_entry('inventory/{0}/state'.format(instance_name)) or "STOPPED").lower()
+            instance_state = str(self._get_data_entry(f'inventory/{instance_name}/state') or "STOPPED").lower()
 
             # Only consider instances that match the "state" filter, if self.state is not None
             if self.filter:
                 if self.filter.lower() != instance_state:
                     continue
             # add instance
+            instance_name = make_unsafe(instance_name)
             self.inventory.add_host(instance_name)
             # add network information
             self.build_inventory_network(instance_name)
             # add os
-            v = self._get_data_entry('inventory/{0}/os'.format(instance_name))
+            v = self._get_data_entry(f'inventory/{instance_name}/os')
             if v:
-                self.inventory.set_variable(instance_name, 'ansible_lxd_os', v.lower())
+                self.inventory.set_variable(instance_name, 'ansible_lxd_os', make_unsafe(v.lower()))
             # add release
-            v = self._get_data_entry('inventory/{0}/release'.format(instance_name))
+            v = self._get_data_entry(f'inventory/{instance_name}/release')
             if v:
-                self.inventory.set_variable(instance_name, 'ansible_lxd_release', v.lower())
+                self.inventory.set_variable(
+                    instance_name, 'ansible_lxd_release', make_unsafe(v.lower()))
             # add profile
-            self.inventory.set_variable(instance_name, 'ansible_lxd_profile', self._get_data_entry('inventory/{0}/profile'.format(instance_name)))
+            self.inventory.set_variable(
+                instance_name, 'ansible_lxd_profile', make_unsafe(self._get_data_entry(f'inventory/{instance_name}/profile')))
             # add state
-            self.inventory.set_variable(instance_name, 'ansible_lxd_state', instance_state)
+            self.inventory.set_variable(
+                instance_name, 'ansible_lxd_state', make_unsafe(instance_state))
             # add type
-            self.inventory.set_variable(instance_name, 'ansible_lxd_type', self._get_data_entry('inventory/{0}/type'.format(instance_name)))
+            self.inventory.set_variable(
+                instance_name, 'ansible_lxd_type', make_unsafe(self._get_data_entry(f'inventory/{instance_name}/type')))
             # add location information
-            if self._get_data_entry('inventory/{0}/location'.format(instance_name)) != "none":  # wrong type by lxd 'none' != 'None'
-                self.inventory.set_variable(instance_name, 'ansible_lxd_location', self._get_data_entry('inventory/{0}/location'.format(instance_name)))
+            if self._get_data_entry(f'inventory/{instance_name}/location') != "none":  # wrong type by lxd 'none' != 'None'
+                self.inventory.set_variable(
+                    instance_name, 'ansible_lxd_location', make_unsafe(self._get_data_entry(f'inventory/{instance_name}/location')))
             # add VLAN_ID information
-            if self._get_data_entry('inventory/{0}/vlan_ids'.format(instance_name)):
-                self.inventory.set_variable(instance_name, 'ansible_lxd_vlan_ids', self._get_data_entry('inventory/{0}/vlan_ids'.format(instance_name)))
+            if self._get_data_entry(f'inventory/{instance_name}/vlan_ids'):
+                self.inventory.set_variable(
+                    instance_name, 'ansible_lxd_vlan_ids', make_unsafe(self._get_data_entry(f'inventory/{instance_name}/vlan_ids')))
             # add project
-            self.inventory.set_variable(instance_name, 'ansible_lxd_project', self._get_data_entry('inventory/{0}/project'.format(instance_name)))
+            self.inventory.set_variable(
+                instance_name, 'ansible_lxd_project', make_unsafe(self._get_data_entry(f'inventory/{instance_name}/project')))
 
     def build_inventory_groups_location(self, group_name):
         """create group by attribute: location
@@ -782,7 +794,7 @@ class InventoryModule(BaseInventoryPlugin):
             network = ipaddress.ip_network(to_text(self.groupby[group_name].get('attribute')))
         except ValueError as err:
             raise AnsibleParserError(
-                'Error while parsing network range {0}: {1}'.format(self.groupby[group_name].get('attribute'), to_native(err)))
+                f"Error while parsing network range {self.groupby[group_name].get('attribute')}: {err}")
 
         for instance_name in self.inventory.hosts:
             if self.data['inventory'][instance_name].get('network_interfaces') is not None:
@@ -987,13 +999,13 @@ class InventoryModule(BaseInventoryPlugin):
             elif self.groupby[group_name].get('type') == 'project':
                 self.build_inventory_groups_project(group_name)
             else:
-                raise AnsibleParserError('Unknown group type: {0}'.format(to_native(group_name)))
+                raise AnsibleParserError(f'Unknown group type: {to_native(group_name)}')
 
         if self.groupby:
             for group_name in self.groupby:
                 if not group_name.isalnum():
-                    raise AnsibleParserError('Invalid character(s) in groupname: {0}'.format(to_native(group_name)))
-                group_type(group_name)
+                    raise AnsibleParserError(f'Invalid character(s) in groupname: {to_native(group_name)}')
+                group_type(make_unsafe(group_name))
 
     def build_inventory(self):
         """Build dynamic inventory
@@ -1029,7 +1041,7 @@ class InventoryModule(BaseInventoryPlugin):
             None"""
         iter_keys = list(self.data['instances'].keys())
         for instance_name in iter_keys:
-            if self._get_data_entry('instances/{0}/instances/metadata/type'.format(instance_name)) != self.type_filter:
+            if self._get_data_entry(f'instances/{instance_name}/instances/metadata/type') != self.type_filter:
                 del self.data['instances'][instance_name]
 
     def _populate(self):
@@ -1082,9 +1094,7 @@ class InventoryModule(BaseInventoryPlugin):
         Returns:
             None"""
         if IPADDRESS_IMPORT_ERROR:
-            raise_from(
-                AnsibleError('another_library must be installed to use this plugin'),
-                IPADDRESS_IMPORT_ERROR)
+            raise AnsibleError('another_library must be installed to use this plugin') from IPADDRESS_IMPORT_ERROR
 
         super(InventoryModule, self).parse(inventory, loader, path, cache=False)
         # Read the inventory YAML file
@@ -1110,6 +1120,6 @@ class InventoryModule(BaseInventoryPlugin):
             self.url = self.get_option('url')
         except Exception as err:
             raise AnsibleParserError(
-                'All correct options required: {0}'.format(to_native(err)))
+                f'All correct options required: {err}')
         # Call our internal helper to populate the dynamic inventory
         self._populate()
