@@ -24,11 +24,17 @@ options:
   idrac_user:
     required: true
     type: str
-    description: iDRAC username.
+    description:
+      - iDRAC username.
+      - If the username is not provided, then the environment variable E(IDRAC_USERNAME) is used.
+      - "Example: export IDRAC_USERNAME=username"
   idrac_password:
     required: true
     type: str
-    description: iDRAC user password.
+    description:
+      - iDRAC user password.
+      - If the password is not provided, then the environment variable E(IDRAC_PASSWORD) is used.
+      - "Example: export IDRAC_PASSWORD=password"
     aliases: ['idrac_pwd']
   idrac_port:
     type: int
