@@ -327,6 +327,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -386,8 +387,8 @@ EXAMPLES = '''
             - power-blade-down
             - confsync_failure
           hosts:
-            - ha-direct: enable
-              host-type: any
+            - ha_direct: enable
+              host_type: any
               id: 1
           id: 1
           name: "ansible-test"
