@@ -281,6 +281,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -294,8 +295,8 @@ EXAMPLES = '''
         devprof: "ansible-test" # system template name, could find it in FortiManager UI: Device Manager --> Provisioning Templates --> System Templates
         state: present
         devprof_system_snmp_user:
-          auth-proto: md5
-          auth-pwd: "fortinet"
+          auth_proto: md5
+          auth_pwd: "fortinet"
           events:
             - cpu-high
             - mem-low
@@ -341,7 +342,7 @@ EXAMPLES = '''
             - per-cpu-high
             - power-blade-down
             - confsync_failure
-          ha-direct: disable
+          ha_direct: disable
           name: "ansible-test"
 
 - name: Gathering fortimanager facts
