@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -103,6 +106,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -111,15 +115,15 @@ EXAMPLES = '''
     - name: MSN Hotmail.
       fortinet.fortimanager.fmgr_emailfilter_profile_msnhotmail:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         profile: <your own value>
         emailfilter_profile_msnhotmail:
-          log: <value in [disable, enable]>
-          log_all: <value in [disable, enable]>
+          # log: <value in [disable, enable]>
+          # log_all: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -177,6 +181,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'profile': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'emailfilter_profile_msnhotmail': {
             'type': 'dict',
             'v_range': [['6.2.0', '']],
