@@ -86,6 +86,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -94,15 +95,15 @@ EXAMPLES = '''
     - name: Reclaim management tunnel to device.
       fortinet.fortimanager.fmgr_exec_fgfm_reclaimdevtunnel:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         device_name: <your own value>
         exec_fgfm_reclaimdevtunnel:
-          flags:
-            - "force"
-            - "get_info"
+          # flags:
+          #   - "force"
+          #   - "get_info"
 '''
 
 RETURN = '''
