@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -136,6 +139,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -144,8 +148,8 @@ EXAMPLES = '''
     - name: QUIC setting.
       fortinet.fortimanager.fmgr_firewall_accessproxy_apigateway6_quic:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -220,6 +224,7 @@ def main():
         'access_proxy': {'type': 'str'},
         'api-gateway6': {'type': 'str', 'api_name': 'api_gateway6'},
         'api_gateway6': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_accessproxy_apigateway6_quic': {
             'type': 'dict',
             'v_range': [['7.4.1', '']],
