@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -278,6 +281,7 @@ options:
                     - 'device-identification'
                     - 'rsso'
                     - 'external-resource'
+                    - 'obsolete'
             global_object:
                 aliases: ['global-object']
                 type: int
@@ -360,6 +364,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -376,12 +381,12 @@ EXAMPLES = '''
           _scope:
             - name: FGT_AWS # need a valid device name
               vdom: root # need a valid vdom name under the device
-          allow-routing: disable # <value in [disable, enable]>
-          cache-ttl: 0
+          allow_routing: disable # <value in [disable, enable]>
+          cache_ttl: 0
           color: 1
           comment: "ansible-comment"
           subnet: "222.222.222.101/32"
-          subnet-name: "ansible-test"
+          subnet_name: "ansible-test"
           type: ipmask # <value in [ipmask, iprange, fqdn, ...]>
           visibility: enable
 
@@ -459,6 +464,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'address': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_address_dynamicmapping': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -511,7 +517,7 @@ def main():
                     'v_range': [['6.2.2', '']],
                     'choices': [
                         'sdn', 'clearpass-spt', 'fsso', 'ems-tag', 'swc-tag', 'fortivoice-tag', 'fortinac-tag', 'fortipolicy-tag',
-                        'device-identification', 'rsso', 'external-resource'
+                        'device-identification', 'rsso', 'external-resource', 'obsolete'
                     ],
                     'type': 'str'
                 },
