@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -283,6 +286,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -291,41 +295,41 @@ EXAMPLES = '''
     - name: Message filter.
       fortinet.fortimanager.fmgr_firewall_gtp_messagefilter:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         gtp: <your own value>
         firewall_gtp_messagefilter:
-          create_aa_pdp: <value in [allow, deny]>
-          create_mbms: <value in [allow, deny]>
-          create_pdp: <value in [allow, deny]>
-          data_record: <value in [allow, deny]>
-          delete_aa_pdp: <value in [allow, deny]>
-          delete_mbms: <value in [allow, deny]>
-          delete_pdp: <value in [allow, deny]>
-          echo: <value in [allow, deny]>
-          error_indication: <value in [allow, deny]>
-          failure_report: <value in [allow, deny]>
-          fwd_relocation: <value in [allow, deny]>
-          fwd_srns_context: <value in [allow, deny]>
-          gtp_pdu: <value in [allow, deny]>
-          identification: <value in [allow, deny]>
-          mbms_notification: <value in [allow, deny]>
-          node_alive: <value in [allow, deny]>
-          note_ms_present: <value in [allow, deny]>
-          pdu_notification: <value in [allow, deny]>
-          ran_info: <value in [allow, deny]>
-          redirection: <value in [allow, deny]>
-          relocation_cancel: <value in [allow, deny]>
-          send_route: <value in [allow, deny]>
-          sgsn_context: <value in [allow, deny]>
-          support_extension: <value in [allow, deny]>
-          unknown_message_action: <value in [allow, deny]>
-          update_mbms: <value in [allow, deny]>
-          update_pdp: <value in [allow, deny]>
-          version_not_support: <value in [allow, deny]>
+          # create_aa_pdp: <value in [allow, deny]>
+          # create_mbms: <value in [allow, deny]>
+          # create_pdp: <value in [allow, deny]>
+          # data_record: <value in [allow, deny]>
+          # delete_aa_pdp: <value in [allow, deny]>
+          # delete_mbms: <value in [allow, deny]>
+          # delete_pdp: <value in [allow, deny]>
+          # echo: <value in [allow, deny]>
+          # error_indication: <value in [allow, deny]>
+          # failure_report: <value in [allow, deny]>
+          # fwd_relocation: <value in [allow, deny]>
+          # fwd_srns_context: <value in [allow, deny]>
+          # gtp_pdu: <value in [allow, deny]>
+          # identification: <value in [allow, deny]>
+          # mbms_notification: <value in [allow, deny]>
+          # node_alive: <value in [allow, deny]>
+          # note_ms_present: <value in [allow, deny]>
+          # pdu_notification: <value in [allow, deny]>
+          # ran_info: <value in [allow, deny]>
+          # redirection: <value in [allow, deny]>
+          # relocation_cancel: <value in [allow, deny]>
+          # send_route: <value in [allow, deny]>
+          # sgsn_context: <value in [allow, deny]>
+          # support_extension: <value in [allow, deny]>
+          # unknown_message_action: <value in [allow, deny]>
+          # update_mbms: <value in [allow, deny]>
+          # update_pdp: <value in [allow, deny]>
+          # version_not_support: <value in [allow, deny]>
 '''
 
 RETURN = '''
@@ -383,6 +387,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'gtp': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_gtp_messagefilter': {
             'type': 'dict',
             'v_range': [['6.2.0', '6.2.13']],
