@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -128,6 +131,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -136,23 +140,23 @@ EXAMPLES = '''
     - name: Configure MAPI protocol options.
       fortinet.fortimanager.fmgr_firewall_profileprotocoloptions_mapi:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         profile_protocol_options: <your own value>
         firewall_profileprotocoloptions_mapi:
-          options:
-            - "fragmail"
-            - "oversize"
-            - "no-content-summary"
-          oversize_limit: <integer>
-          ports: <list or integer>
-          scan_bzip2: <value in [disable, enable]>
-          status: <value in [disable, enable]>
-          uncompressed_nest_limit: <integer>
-          uncompressed_oversize_limit: <integer>
+          # options:
+          #   - "fragmail"
+          #   - "oversize"
+          #   - "no-content-summary"
+          # oversize_limit: <integer>
+          # ports: <list or integer>
+          # scan_bzip2: <value in [disable, enable]>
+          # status: <value in [disable, enable]>
+          # uncompressed_nest_limit: <integer>
+          # uncompressed_oversize_limit: <integer>
 '''
 
 RETURN = '''
@@ -211,6 +215,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'profile-protocol-options': {'type': 'str', 'api_name': 'profile_protocol_options'},
         'profile_protocol_options': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_profileprotocoloptions_mapi': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
