@@ -99,19 +99,20 @@ options:
         suboptions:
             attr:
                 type: str
-                description: No description.
+                description: Attr.
                 choices:
                     - 'label'
                     - 'global-label'
             name:
                 type: str
-                description: No description.
+                description: Name.
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -120,8 +121,8 @@ EXAMPLES = '''
     - name: Configure IPv6 policies.
       fortinet.fortimanager.fmgr_pm_config_pblock_firewall_policy6_sectionvalue:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -129,8 +130,8 @@ EXAMPLES = '''
         policy6: <your own value>
         state: present # <value in [present, absent]>
         pm_config_pblock_firewall_policy6_sectionvalue:
-          attr: <value in [label, global-label]>
-          name: <string>
+          # attr: <value in [label, global-label]>
+          # name: <string>
 '''
 
 RETURN = '''
@@ -174,21 +175,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/pblock/{pblock}/firewall/policy6/{policy6}/section value'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/pblock/{pblock}/firewall/policy6/{policy6}/section value'
-    ]
-
     url_params = ['adom', 'pblock', 'policy6']
     module_primary_key = None
     module_arg_spec = {
@@ -197,12 +191,11 @@ def main():
         'policy6': {'required': True, 'type': 'str'},
         'pm_config_pblock_firewall_policy6_sectionvalue': {
             'type': 'dict',
-            'v_range': [['7.0.3', '']],
+            'v_range': [['7.0.3', '7.6.2']],
             'options': {
-                'attr': {'v_range': [['7.0.3', '']], 'choices': ['label', 'global-label'], 'type': 'str'},
-                'name': {'v_range': [['7.0.3', '']], 'type': 'str'}
+                'attr': {'v_range': [['7.0.3', '7.6.2']], 'choices': ['label', 'global-label'], 'type': 'str'},
+                'name': {'v_range': [['7.0.3', '7.6.2']], 'type': 'str'}
             }
-
         }
     }
 
@@ -211,17 +204,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'pm_config_pblock_firewall_policy6_sectionvalue'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('object member', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_object_member(argument_specs=module_arg_spec)
+    fmgr.process_object_member()
 
     module.exit_json(meta=module.params)
 
