@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -95,12 +98,14 @@ options:
         required: false
         type: dict
         suboptions:
-            802-1x:
+            802_1x:
+                aliases: ['802-1x']
                 type: str
-                description: Deprecated, please rename it to 802_1x. '802.'
-            bounce-port-link:
+                description: '802.'
+            bounce_port_link:
+                aliases: ['bounce-port-link']
                 type: str
-                description: Deprecated, please rename it to bounce_port_link. Enable/disable bouncing
+                description: Enable/disable bouncing
                 choices:
                     - 'disable'
                     - 'enable'
@@ -119,15 +124,18 @@ options:
             host:
                 type: str
                 description: Match policy based on host.
-            hw-vendor:
+            hw_vendor:
+                aliases: ['hw-vendor']
                 type: str
-                description: Deprecated, please rename it to hw_vendor. Match policy based on hardware vendor.
-            interface-tags:
+                description: Match policy based on hardware vendor.
+            interface_tags:
+                aliases: ['interface-tags']
                 type: raw
-                description: (list) Deprecated, please rename it to interface_tags. Match policy based on the FortiSwitch interface object tags.
-            lldp-profile:
+                description: (list) Match policy based on the FortiSwitch interface object tags.
+            lldp_profile:
+                aliases: ['lldp-profile']
                 type: str
-                description: Deprecated, please rename it to lldp_profile. LLDP profile to be applied when using this policy.
+                description: LLDP profile to be applied when using this policy.
             mac:
                 type: str
                 description: Match policy based on MAC address.
@@ -135,9 +143,10 @@ options:
                 type: str
                 description: Policy name.
                 required: true
-            qos-policy:
+            qos_policy:
+                aliases: ['qos-policy']
                 type: str
-                description: Deprecated, please rename it to qos_policy. QoS policy to be applied when using this policy.
+                description: QoS policy to be applied when using this policy.
             status:
                 type: str
                 description: Enable/disable policy.
@@ -147,24 +156,46 @@ options:
             type:
                 type: str
                 description: Match policy based on type.
-            vlan-policy:
+            vlan_policy:
+                aliases: ['vlan-policy']
                 type: str
-                description: Deprecated, please rename it to vlan_policy. VLAN policy to be applied when using this policy.
-            match-period:
+                description: VLAN policy to be applied when using this policy.
+            match_period:
+                aliases: ['match-period']
                 type: int
-                description: Deprecated, please rename it to match_period. Number of days the matched devices will be retained
-            match-type:
+                description: Number of days the matched devices will be retained
+            match_type:
+                aliases: ['match-type']
                 type: str
-                description: Deprecated, please rename it to match_type. Match and retain the devices based on the type.
+                description: Match and retain the devices based on the type.
                 choices:
                     - 'dynamic'
                     - 'override'
+            bounce_port_duration:
+                aliases: ['bounce-port-duration']
+                type: int
+                description: Bounce duration in seconds of a switch port where this policy is applied.
+            poe_reset:
+                aliases: ['poe-reset']
+                type: str
+                description: Enable/disable POE reset of a switch port where this policy is applied.
+                choices:
+                    - 'disable'
+                    - 'enable'
+            match_remove:
+                aliases: ['match-remove']
+                type: str
+                description: Options to remove the matched override devices.
+                choices:
+                    - 'link-down'
+                    - 'default'
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -173,31 +204,34 @@ EXAMPLES = '''
     - name: Port policies with matching criteria and actions.
       fortinet.fortimanager.fmgr_switchcontroller_dynamicportpolicy_policy:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         dynamic_port_policy: <your own value>
         state: present # <value in [present, absent]>
         switchcontroller_dynamicportpolicy_policy:
-          802_1x: <string>
-          bounce_port_link: <value in [disable, enable]>
-          category: <value in [device, interface-tag]>
-          description: <string>
-          family: <string>
-          host: <string>
-          hw_vendor: <string>
-          interface_tags: <list or string>
-          lldp_profile: <string>
-          mac: <string>
-          name: <string>
-          qos_policy: <string>
-          status: <value in [disable, enable]>
-          type: <string>
-          vlan_policy: <string>
-          match_period: <integer>
-          match_type: <value in [dynamic, override]>
+          name: "your value" # Required variable, string
+          # 802_1x: <string>
+          # bounce_port_link: <value in [disable, enable]>
+          # category: <value in [device, interface-tag]>
+          # description: <string>
+          # family: <string>
+          # host: <string>
+          # hw_vendor: <string>
+          # interface_tags: <list or string>
+          # lldp_profile: <string>
+          # mac: <string>
+          # qos_policy: <string>
+          # status: <value in [disable, enable]>
+          # type: <string>
+          # vlan_policy: <string>
+          # match_period: <integer>
+          # match_type: <value in [dynamic, override]>
+          # bounce_port_duration: <integer>
+          # poe_reset: <value in [disable, enable]>
+          # match_remove: <value in [link-down, default]>
 '''
 
 RETURN = '''
@@ -241,29 +275,22 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/switch-controller/dynamic-port-policy/{dynamic-port-policy}/policy',
         '/pm/config/global/obj/switch-controller/dynamic-port-policy/{dynamic-port-policy}/policy'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/switch-controller/dynamic-port-policy/{dynamic-port-policy}/policy/{policy}',
-        '/pm/config/global/obj/switch-controller/dynamic-port-policy/{dynamic-port-policy}/policy/{policy}'
-    ]
-
     url_params = ['adom', 'dynamic-port-policy']
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'dynamic-port-policy': {'type': 'str', 'api_name': 'dynamic_port_policy'},
         'dynamic_port_policy': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'switchcontroller_dynamicportpolicy_policy': {
             'type': 'dict',
             'v_range': [['7.2.1', '']],
@@ -284,9 +311,11 @@ def main():
                 'type': {'v_range': [['7.2.1', '']], 'type': 'str'},
                 'vlan-policy': {'v_range': [['7.2.1', '']], 'type': 'str'},
                 'match-period': {'v_range': [['7.4.3', '']], 'type': 'int'},
-                'match-type': {'v_range': [['7.4.3', '']], 'choices': ['dynamic', 'override'], 'type': 'str'}
+                'match-type': {'v_range': [['7.4.3', '']], 'choices': ['dynamic', 'override'], 'type': 'str'},
+                'bounce-port-duration': {'v_range': [['7.6.2', '']], 'type': 'int'},
+                'poe-reset': {'v_range': [['7.6.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'match-remove': {'v_range': [['7.6.3', '']], 'choices': ['link-down', 'default'], 'type': 'str'}
             }
-
         }
     }
 
@@ -295,14 +324,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'switchcontroller_dynamicportpolicy_policy'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
