@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -146,6 +149,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -180,7 +184,7 @@ EXAMPLES = '''
           params:
             adom: "ansible"
             server: "1" # id
-            reserved-address: "your_value"
+            reserved_address: "your_value"
 '''
 
 RETURN = '''
@@ -238,6 +242,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'server': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'system_dhcp_server_reservedaddress': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
