@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -113,6 +116,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -121,8 +125,8 @@ EXAMPLES = '''
     - name: Configure AWS external account list.
       fortinet.fortimanager.fmgr_system_sdnconnector_externalaccountlist:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -190,13 +194,14 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'sdn-connector': {'type': 'str', 'api_name': 'sdn_connector'},
         'sdn_connector': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'system_sdnconnector_externalaccountlist': {
             'type': 'dict',
             'v_range': [['7.0.3', '']],
             'options': {
                 'region-list': {'v_range': [['7.0.3', '']], 'type': 'raw'},
                 'role-arn': {'v_range': [['7.0.3', '']], 'type': 'str'},
-                'external-id': {'v_range': [['7.0.5', '7.0.13'], ['7.2.1', '']], 'type': 'str'}
+                'external-id': {'v_range': [['7.0.5', '7.0.14'], ['7.2.1', '']], 'type': 'str'}
             }
         }
     }
