@@ -112,6 +112,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -120,17 +121,17 @@ EXAMPLES = '''
     - name: Configure system web proxy.
       fortinet.fortimanager.fmgr_system_webproxy:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_webproxy:
-          address: <string>
-          mode: <value in [proxy, tunnel]>
-          password: <list or string>
-          port: <integer>
-          status: <value in [disable, enable]>
-          username: <string>
+          # address: <string>
+          # mode: <value in [proxy, tunnel]>
+          # password: <list or string>
+          # port: <integer>
+          # status: <value in [disable, enable]>
+          # username: <string>
 '''
 
 RETURN = '''
