@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -119,6 +122,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -127,8 +131,8 @@ EXAMPLES = '''
     - name: List of keywords.
       fortinet.fortimanager.fmgr_videofilter_keyword_word:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -196,6 +200,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'keyword': {'required': True, 'type': 'str', 'no_log': False},
+        'revision_note': {'type': 'str'},
         'videofilter_keyword_word': {
             'type': 'dict',
             'no_log': False,
