@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -105,9 +108,10 @@ options:
                             - 'bypass'
                             - 'monitor'
                             - 'allow'
-                    channel-id:
+                    channel_id:
+                        aliases: ['channel-id']
                         type: str
-                        description: Deprecated, please rename it to channel_id. Channel ID.
+                        description: Channel ID.
                     comment:
                         type: str
                         description: Comment.
@@ -121,9 +125,10 @@ options:
             name:
                 type: str
                 description: Name.
-            default-action:
+            default_action:
+                aliases: ['default-action']
                 type: str
-                description: Deprecated, please rename it to default_action. YouTube channel filter default action.
+                description: YouTube channel filter default action.
                 choices:
                     - 'monitor'
                     - 'block'
@@ -134,9 +139,10 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            override-category:
+            override_category:
+                aliases: ['override-category']
                 type: str
-                description: Deprecated, please rename it to override_category. Enable/disable overriding category filtering result.
+                description: Enable/disable overriding category filtering result.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -146,6 +152,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -154,25 +161,24 @@ EXAMPLES = '''
     - name: Configure YouTube channel filter.
       fortinet.fortimanager.fmgr_videofilter_youtubechannelfilter:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         videofilter_youtubechannelfilter:
-          comment: <string>
-          entries:
-            -
-              action: <value in [block, bypass, monitor, ...]>
-              channel_id: <string>
-              comment: <string>
-              id: <integer>
-          id: <integer>
-          name: <string>
-          default_action: <value in [monitor, block, allow]>
-          log: <value in [disable, enable]>
-          override_category: <value in [disable, enable]>
+          id: 0 # Required variable, integer
+          # comment: <string>
+          # entries:
+          #   - action: <value in [block, bypass, monitor, ...]>
+          #     channel_id: <string>
+          #     comment: <string>
+          #     id: <integer>
+          # name: <string>
+          # default_action: <value in [monitor, block, allow]>
+          # log: <value in [disable, enable]>
+          # override_category: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -216,27 +222,20 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/videofilter/youtube-channel-filter',
         '/pm/config/global/obj/videofilter/youtube-channel-filter'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/videofilter/youtube-channel-filter/{youtube-channel-filter}',
-        '/pm/config/global/obj/videofilter/youtube-channel-filter/{youtube-channel-filter}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'id'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'videofilter_youtubechannelfilter': {
             'type': 'dict',
             'v_range': [['7.0.0', '']],
@@ -257,9 +256,8 @@ def main():
                 'name': {'v_range': [['7.0.0', '']], 'type': 'str'},
                 'default-action': {'v_range': [['7.0.1', '']], 'choices': ['monitor', 'block', 'allow'], 'type': 'str'},
                 'log': {'v_range': [['7.0.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'override-category': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'override-category': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -268,14 +266,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'videofilter_youtubechannelfilter'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
