@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -89,21 +92,24 @@ options:
         required: false
         type: dict
         suboptions:
-            add-route:
+            add_route:
+                aliases: ['add-route']
                 type: str
-                description: Deprecated, please rename it to add_route. Add-Route.
+                description: Add route.
                 choices:
                     - 'disable'
                     - 'enable'
-            assign-ip:
+            assign_ip:
+                aliases: ['assign-ip']
                 type: str
-                description: Deprecated, please rename it to assign_ip. Assign-Ip.
+                description: Assign ip.
                 choices:
                     - 'disable'
                     - 'enable'
-            assign-ip-from:
+            assign_ip_from:
+                aliases: ['assign-ip-from']
                 type: str
-                description: Deprecated, please rename it to assign_ip_from. Assign-Ip-From.
+                description: Assign ip from.
                 choices:
                     - 'range'
                     - 'usrgrp'
@@ -118,39 +124,44 @@ options:
             authusrgrp:
                 type: str
                 description: Authusrgrp.
-            auto-configuration:
+            auto_configuration:
+                aliases: ['auto-configuration']
                 type: str
-                description: Deprecated, please rename it to auto_configuration. Auto-Configuration.
+                description: Auto configuration.
                 choices:
                     - 'disable'
                     - 'enable'
             automatic_routing:
                 type: str
-                description: Automatic_Routing.
+                description: Automatic routing.
                 choices:
                     - 'disable'
                     - 'enable'
             banner:
                 type: str
                 description: Banner.
-            default-gateway:
+            default_gateway:
+                aliases: ['default-gateway']
                 type: str
-                description: Deprecated, please rename it to default_gateway. Default-Gateway.
-            dhcp-server:
+                description: Default gateway.
+            dhcp_server:
+                aliases: ['dhcp-server']
                 type: str
-                description: Deprecated, please rename it to dhcp_server. Dhcp-Server.
+                description: Dhcp server.
                 choices:
                     - 'disable'
                     - 'enable'
-            dns-mode:
+            dns_mode:
+                aliases: ['dns-mode']
                 type: str
-                description: Deprecated, please rename it to dns_mode. Dns-Mode.
+                description: Dns mode.
                 choices:
                     - 'auto'
                     - 'manual'
-            dns-service:
+            dns_service:
+                aliases: ['dns-service']
                 type: str
-                description: Deprecated, please rename it to dns_service. Dns-Service.
+                description: Dns service.
                 choices:
                     - 'default'
                     - 'specify'
@@ -163,10 +174,10 @@ options:
                 description: Extgw.
             extgw_hubip:
                 type: str
-                description: Extgw_Hubip.
+                description: Extgw hubip.
             extgw_p2_per_net:
                 type: str
-                description: Extgw_P2_Per_Net.
+                description: Extgw p2 per net.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -175,7 +186,7 @@ options:
                 description: Extgwip.
             hub_iface:
                 type: raw
-                description: (list or str) Hub_Iface.
+                description: (list or str) Hub iface.
             id:
                 type: int
                 description: Id.
@@ -183,85 +194,105 @@ options:
             iface:
                 type: raw
                 description: (list or str) Iface.
-            ip-range:
+            ip_range:
+                aliases: ['ip-range']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to ip_range. Ip-Range.
+                description: Ip range.
                 suboptions:
-                    end-ip:
+                    end_ip:
+                        aliases: ['end-ip']
                         type: str
-                        description: Deprecated, please rename it to end_ip. End-Ip.
+                        description: End ip.
                     id:
                         type: int
                         description: Id.
-                    start-ip:
+                    start_ip:
+                        aliases: ['start-ip']
                         type: str
-                        description: Deprecated, please rename it to start_ip. Start-Ip.
-            ipsec-lease-hold:
+                        description: Start ip.
+            ipsec_lease_hold:
+                aliases: ['ipsec-lease-hold']
                 type: int
-                description: Deprecated, please rename it to ipsec_lease_hold. Ipsec-Lease-Hold.
-            ipv4-dns-server1:
+                description: Ipsec lease hold.
+            ipv4_dns_server1:
+                aliases: ['ipv4-dns-server1']
                 type: str
-                description: Deprecated, please rename it to ipv4_dns_server1. Ipv4-Dns-Server1.
-            ipv4-dns-server2:
+                description: Ipv4 dns server1.
+            ipv4_dns_server2:
+                aliases: ['ipv4-dns-server2']
                 type: str
-                description: Deprecated, please rename it to ipv4_dns_server2. Ipv4-Dns-Server2.
-            ipv4-dns-server3:
+                description: Ipv4 dns server2.
+            ipv4_dns_server3:
+                aliases: ['ipv4-dns-server3']
                 type: str
-                description: Deprecated, please rename it to ipv4_dns_server3. Ipv4-Dns-Server3.
-            ipv4-end-ip:
+                description: Ipv4 dns server3.
+            ipv4_end_ip:
+                aliases: ['ipv4-end-ip']
                 type: str
-                description: Deprecated, please rename it to ipv4_end_ip. Ipv4-End-Ip.
-            ipv4-exclude-range:
+                description: Ipv4 end ip.
+            ipv4_exclude_range:
+                aliases: ['ipv4-exclude-range']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to ipv4_exclude_range. Ipv4-Exclude-Range.
+                description: Ipv4 exclude range.
                 suboptions:
-                    end-ip:
+                    end_ip:
+                        aliases: ['end-ip']
                         type: str
-                        description: Deprecated, please rename it to end_ip. End-Ip.
+                        description: End ip.
                     id:
                         type: int
                         description: Id.
-                    start-ip:
+                    start_ip:
+                        aliases: ['start-ip']
                         type: str
-                        description: Deprecated, please rename it to start_ip. Start-Ip.
-            ipv4-netmask:
+                        description: Start ip.
+            ipv4_netmask:
+                aliases: ['ipv4-netmask']
                 type: str
-                description: Deprecated, please rename it to ipv4_netmask. Ipv4-Netmask.
-            ipv4-split-include:
+                description: Ipv4 netmask.
+            ipv4_split_include:
+                aliases: ['ipv4-split-include']
                 type: str
-                description: Deprecated, please rename it to ipv4_split_include. Ipv4-Split-Include.
-            ipv4-start-ip:
+                description: Ipv4 split include.
+            ipv4_start_ip:
+                aliases: ['ipv4-start-ip']
                 type: str
-                description: Deprecated, please rename it to ipv4_start_ip. Ipv4-Start-Ip.
-            ipv4-wins-server1:
+                description: Ipv4 start ip.
+            ipv4_wins_server1:
+                aliases: ['ipv4-wins-server1']
                 type: str
-                description: Deprecated, please rename it to ipv4_wins_server1. Ipv4-Wins-Server1.
-            ipv4-wins-server2:
+                description: Ipv4 wins server1.
+            ipv4_wins_server2:
+                aliases: ['ipv4-wins-server2']
                 type: str
-                description: Deprecated, please rename it to ipv4_wins_server2. Ipv4-Wins-Server2.
-            local-gw:
+                description: Ipv4 wins server2.
+            local_gw:
+                aliases: ['local-gw']
                 type: str
-                description: Deprecated, please rename it to local_gw. Local-Gw.
+                description: Local gw.
             localid:
                 type: str
                 description: Localid.
-            mode-cfg:
+            mode_cfg:
+                aliases: ['mode-cfg']
                 type: str
-                description: Deprecated, please rename it to mode_cfg. Mode-Cfg.
+                description: Mode cfg.
                 choices:
                     - 'disable'
                     - 'enable'
-            mode-cfg-ip-version:
+            mode_cfg_ip_version:
+                aliases: ['mode-cfg-ip-version']
                 type: str
-                description: Deprecated, please rename it to mode_cfg_ip_version. Mode-Cfg-Ip-Version.
+                description: Mode cfg ip version.
                 choices:
                     - '4'
                     - '6'
-            net-device:
+            net_device:
+                aliases: ['net-device']
                 type: str
-                description: Deprecated, please rename it to net_device. Net-Device.
+                description: Net device.
                 choices:
                     - 'disable'
                     - 'enable'
@@ -286,7 +317,7 @@ options:
             protected_subnet:
                 type: list
                 elements: dict
-                description: Protected_Subnet.
+                description: Protected subnet.
                 suboptions:
                     addr:
                         type: raw
@@ -294,29 +325,32 @@ options:
                     seq:
                         type: int
                         description: Seq.
-            public-ip:
+            public_ip:
+                aliases: ['public-ip']
                 type: str
-                description: Deprecated, please rename it to public_ip. Public-Ip.
+                description: Public ip.
             role:
                 type: str
                 description: Role.
                 choices:
                     - 'hub'
                     - 'spoke'
-            route-overlap:
+            route_overlap:
+                aliases: ['route-overlap']
                 type: str
-                description: Deprecated, please rename it to route_overlap. Route-Overlap.
+                description: Route overlap.
                 choices:
                     - 'use-old'
                     - 'use-new'
                     - 'allow'
-            spoke-zone:
+            spoke_zone:
+                aliases: ['spoke-zone']
                 type: raw
-                description: (list or str) Deprecated, please rename it to spoke_zone. Spoke-Zone.
+                description: (list or str) Spoke zone.
             summary_addr:
                 type: list
                 elements: dict
-                description: Summary_Addr.
+                description: Summary addr.
                 suboptions:
                     addr:
                         type: str
@@ -327,27 +361,31 @@ options:
                     seq:
                         type: int
                         description: Seq.
-            tunnel-search:
+            tunnel_search:
+                aliases: ['tunnel-search']
                 type: str
-                description: Deprecated, please rename it to tunnel_search. Tunnel-Search.
+                description: Tunnel search.
                 choices:
                     - 'selectors'
                     - 'nexthop'
-            unity-support:
+            unity_support:
+                aliases: ['unity-support']
                 type: str
-                description: Deprecated, please rename it to unity_support. Unity-Support.
+                description: Unity support.
                 choices:
                     - 'disable'
                     - 'enable'
             usrgrp:
                 type: str
                 description: Usrgrp.
-            vpn-interface-priority:
+            vpn_interface_priority:
+                aliases: ['vpn-interface-priority']
                 type: int
-                description: Deprecated, please rename it to vpn_interface_priority. Vpn-Interface-Priority.
-            vpn-zone:
+                description: Vpn interface priority.
+            vpn_zone:
+                aliases: ['vpn-zone']
                 type: raw
-                description: (list or str) Deprecated, please rename it to vpn_zone. Vpn-Zone.
+                description: (list or str) Vpn zone.
             vpntable:
                 type: raw
                 description: (list or str) Vpntable.
@@ -360,77 +398,88 @@ options:
                     - 'pap'
                     - 'chap'
                     - 'auto'
-            exchange-interface-ip:
+            exchange_interface_ip:
+                aliases: ['exchange-interface-ip']
                 type: str
-                description: Deprecated, please rename it to exchange_interface_ip. Exchange-Interface-Ip.
+                description: Exchange interface ip.
                 choices:
                     - 'disable'
                     - 'enable'
-            hub-public-ip:
+            hub_public_ip:
+                aliases: ['hub-public-ip']
                 type: str
-                description: Deprecated, please rename it to hub_public_ip. Hub-Public-Ip.
-            ipv4-split-exclude:
+                description: Hub public ip.
+            ipv4_split_exclude:
+                aliases: ['ipv4-split-exclude']
                 type: str
-                description: Deprecated, please rename it to ipv4_split_exclude. Ipv4-Split-Exclude.
-            scope member:
+                description: Ipv4 split exclude.
+            scope_member:
+                aliases: ['scope member']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to scope_member.
+                description: Scope member.
                 suboptions:
                     name:
                         type: str
-                        description: No description.
+                        description: Name.
                     vdom:
                         type: str
-                        description: No description.
-            dhcp-ra-giaddr:
+                        description: Vdom.
+            dhcp_ra_giaddr:
+                aliases: ['dhcp-ra-giaddr']
                 type: str
-                description: Deprecated, please rename it to dhcp_ra_giaddr.
+                description: Dhcp ra giaddr.
             encapsulation:
                 type: str
-                description: No description.
+                description: Encapsulation.
                 choices:
                     - 'tunnel-mode'
                     - 'transport-mode'
-            ipv4-name:
+            ipv4_name:
+                aliases: ['ipv4-name']
                 type: str
-                description: Deprecated, please rename it to ipv4_name.
+                description: Ipv4 name.
             l2tp:
                 type: str
-                description: No description.
+                description: L2tp.
                 choices:
                     - 'disable'
                     - 'enable'
-            auto-discovery-receiver:
+            auto_discovery_receiver:
+                aliases: ['auto-discovery-receiver']
                 type: str
-                description: Deprecated, please rename it to auto_discovery_receiver.
+                description: Auto discovery receiver.
                 choices:
                     - 'disable'
                     - 'enable'
-            auto-discovery-sender:
+            auto_discovery_sender:
+                aliases: ['auto-discovery-sender']
                 type: str
-                description: Deprecated, please rename it to auto_discovery_sender.
+                description: Auto discovery sender.
                 choices:
                     - 'disable'
                     - 'enable'
-            network-id:
+            network_id:
+                aliases: ['network-id']
                 type: int
-                description: Deprecated, please rename it to network_id.
-            network-overlay:
+                description: Network id.
+            network_overlay:
+                aliases: ['network-overlay']
                 type: str
-                description: Deprecated, please rename it to network_overlay.
+                description: Network overlay.
                 choices:
                     - 'enable'
                     - 'disable'
             protocol:
                 type: int
-                description: No description.
+                description: Protocol.
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -439,99 +488,94 @@ EXAMPLES = '''
     - name: VPN node for VPN Manager.
       fortinet.fortimanager.fmgr_vpnmgr_node:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         vpnmgr_node:
-          add_route: <value in [disable, enable]>
-          assign_ip: <value in [disable, enable]>
-          assign_ip_from: <value in [range, usrgrp, dhcp, ...]>
-          authpasswd: <list or string>
-          authusr: <string>
-          authusrgrp: <string>
-          auto_configuration: <value in [disable, enable]>
-          automatic_routing: <value in [disable, enable]>
-          banner: <string>
-          default_gateway: <string>
-          dhcp_server: <value in [disable, enable]>
-          dns_mode: <value in [auto, manual]>
-          dns_service: <value in [default, specify, local]>
-          domain: <string>
-          extgw: <string>
-          extgw_hubip: <string>
-          extgw_p2_per_net: <value in [disable, enable]>
-          extgwip: <string>
-          hub_iface: <list or string>
-          id: <integer>
-          iface: <list or string>
-          ip_range:
-            -
-              end_ip: <string>
-              id: <integer>
-              start_ip: <string>
-          ipsec_lease_hold: <integer>
-          ipv4_dns_server1: <string>
-          ipv4_dns_server2: <string>
-          ipv4_dns_server3: <string>
-          ipv4_end_ip: <string>
-          ipv4_exclude_range:
-            -
-              end_ip: <string>
-              id: <integer>
-              start_ip: <string>
-          ipv4_netmask: <string>
-          ipv4_split_include: <string>
-          ipv4_start_ip: <string>
-          ipv4_wins_server1: <string>
-          ipv4_wins_server2: <string>
-          local_gw: <string>
-          localid: <string>
-          mode_cfg: <value in [disable, enable]>
-          mode_cfg_ip_version: <value in [4, 6]>
-          net_device: <value in [disable, enable]>
-          peer: <list or string>
-          peergrp: <string>
-          peerid: <string>
-          peertype: <value in [any, one, dialup, ...]>
-          protected_subnet:
-            -
-              addr: <list or string>
-              seq: <integer>
-          public_ip: <string>
-          role: <value in [hub, spoke]>
-          route_overlap: <value in [use-old, use-new, allow]>
-          spoke_zone: <list or string>
-          summary_addr:
-            -
-              addr: <string>
-              priority: <integer>
-              seq: <integer>
-          tunnel_search: <value in [selectors, nexthop]>
-          unity_support: <value in [disable, enable]>
-          usrgrp: <string>
-          vpn_interface_priority: <integer>
-          vpn_zone: <list or string>
-          vpntable: <list or string>
-          xauthtype: <value in [disable, client, pap, ...]>
-          exchange_interface_ip: <value in [disable, enable]>
-          hub_public_ip: <string>
-          ipv4_split_exclude: <string>
-          scope_member:
-            -
-              name: <string>
-              vdom: <string>
-          dhcp_ra_giaddr: <string>
-          encapsulation: <value in [tunnel-mode, transport-mode]>
-          ipv4_name: <string>
-          l2tp: <value in [disable, enable]>
-          auto_discovery_receiver: <value in [disable, enable]>
-          auto_discovery_sender: <value in [disable, enable]>
-          network_id: <integer>
-          network_overlay: <value in [enable, disable]>
-          protocol: <integer>
+          id: 0 # Required variable, integer
+          # add_route: <value in [disable, enable]>
+          # assign_ip: <value in [disable, enable]>
+          # assign_ip_from: <value in [range, usrgrp, dhcp, ...]>
+          # authpasswd: <list or string>
+          # authusr: <string>
+          # authusrgrp: <string>
+          # auto_configuration: <value in [disable, enable]>
+          # automatic_routing: <value in [disable, enable]>
+          # banner: <string>
+          # default_gateway: <string>
+          # dhcp_server: <value in [disable, enable]>
+          # dns_mode: <value in [auto, manual]>
+          # dns_service: <value in [default, specify, local]>
+          # domain: <string>
+          # extgw: <string>
+          # extgw_hubip: <string>
+          # extgw_p2_per_net: <value in [disable, enable]>
+          # extgwip: <string>
+          # hub_iface: <list or string>
+          # iface: <list or string>
+          # ip_range:
+          #   - end_ip: <string>
+          #     id: <integer>
+          #     start_ip: <string>
+          # ipsec_lease_hold: <integer>
+          # ipv4_dns_server1: <string>
+          # ipv4_dns_server2: <string>
+          # ipv4_dns_server3: <string>
+          # ipv4_end_ip: <string>
+          # ipv4_exclude_range:
+          #   - end_ip: <string>
+          #     id: <integer>
+          #     start_ip: <string>
+          # ipv4_netmask: <string>
+          # ipv4_split_include: <string>
+          # ipv4_start_ip: <string>
+          # ipv4_wins_server1: <string>
+          # ipv4_wins_server2: <string>
+          # local_gw: <string>
+          # localid: <string>
+          # mode_cfg: <value in [disable, enable]>
+          # mode_cfg_ip_version: <value in [4, 6]>
+          # net_device: <value in [disable, enable]>
+          # peer: <list or string>
+          # peergrp: <string>
+          # peerid: <string>
+          # peertype: <value in [any, one, dialup, ...]>
+          # protected_subnet:
+          #   - addr: <list or string>
+          #     seq: <integer>
+          # public_ip: <string>
+          # role: <value in [hub, spoke]>
+          # route_overlap: <value in [use-old, use-new, allow]>
+          # spoke_zone: <list or string>
+          # summary_addr:
+          #   - addr: <string>
+          #     priority: <integer>
+          #     seq: <integer>
+          # tunnel_search: <value in [selectors, nexthop]>
+          # unity_support: <value in [disable, enable]>
+          # usrgrp: <string>
+          # vpn_interface_priority: <integer>
+          # vpn_zone: <list or string>
+          # vpntable: <list or string>
+          # xauthtype: <value in [disable, client, pap, ...]>
+          # exchange_interface_ip: <value in [disable, enable]>
+          # hub_public_ip: <string>
+          # ipv4_split_exclude: <string>
+          # scope_member:
+          #   - name: <string>
+          #     vdom: <string>
+          # dhcp_ra_giaddr: <string>
+          # encapsulation: <value in [tunnel-mode, transport-mode]>
+          # ipv4_name: <string>
+          # l2tp: <value in [disable, enable]>
+          # auto_discovery_receiver: <value in [disable, enable]>
+          # auto_discovery_sender: <value in [disable, enable]>
+          # network_id: <integer>
+          # network_overlay: <value in [enable, disable]>
+          # protocol: <integer>
 '''
 
 RETURN = '''
@@ -575,27 +619,20 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/vpnmgr/node',
         '/pm/config/global/obj/vpnmgr/node'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/vpnmgr/node/{node}',
-        '/pm/config/global/obj/vpnmgr/node/{node}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'id'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'vpnmgr_node': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -671,25 +708,24 @@ def main():
                 'hub-public-ip': {'v_range': [['6.2.2', '']], 'type': 'str'},
                 'ipv4-split-exclude': {'v_range': [['6.4.6', '']], 'type': 'str'},
                 'scope member': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']],
                     'type': 'list',
                     'options': {
-                        'name': {'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']], 'type': 'str'},
-                        'vdom': {'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']], 'type': 'str'}
+                        'name': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'type': 'str'},
+                        'vdom': {'v_range': [['6.4.7', '6.4.15'], ['7.0.1', '']], 'type': 'str'}
                     },
                     'elements': 'dict'
                 },
-                'dhcp-ra-giaddr': {'v_range': [['6.4.8', '6.4.13'], ['7.0.4', '']], 'type': 'str'},
+                'dhcp-ra-giaddr': {'v_range': [['6.4.8', '6.4.15'], ['7.0.4', '']], 'type': 'str'},
                 'encapsulation': {'v_range': [['7.0.2', '']], 'choices': ['tunnel-mode', 'transport-mode'], 'type': 'str'},
-                'ipv4-name': {'v_range': [['6.4.8', '6.4.13'], ['7.0.4', '']], 'type': 'str'},
+                'ipv4-name': {'v_range': [['6.4.8', '6.4.15'], ['7.0.4', '']], 'type': 'str'},
                 'l2tp': {'v_range': [['7.0.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'auto-discovery-receiver': {'v_range': [['7.0.8', '7.0.10'], ['7.2.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'auto-discovery-sender': {'v_range': [['7.0.8', '7.0.10'], ['7.2.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'network-id': {'v_range': [['7.0.8', '7.0.10'], ['7.2.3', '']], 'type': 'int'},
-                'network-overlay': {'v_range': [['7.0.8', '7.0.10'], ['7.2.3', '']], 'choices': ['enable', 'disable'], 'type': 'str'},
-                'protocol': {'v_range': [['7.4.1', '']], 'type': 'int'}
+                'auto-discovery-receiver': {'v_range': [['7.0.8', '7.0.14'], ['7.2.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'auto-discovery-sender': {'v_range': [['7.0.8', '7.0.14'], ['7.2.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'network-id': {'v_range': [['7.0.8', '7.0.14'], ['7.2.3', '']], 'type': 'int'},
+                'network-overlay': {'v_range': [['7.0.8', '7.0.14'], ['7.2.3', '']], 'choices': ['enable', 'disable'], 'type': 'str'},
+                'protocol': {'v_range': [['7.2.5', '7.2.11'], ['7.4.1', '']], 'type': 'int'}
             }
-
         }
     }
 
@@ -698,17 +734,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'vpnmgr_node'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
