@@ -93,48 +93,58 @@ options:
         required: false
         type: dict
         suboptions:
-            _dynamic-server:
+            _dynamic_server:
+                aliases: ['_dynamic-server']
                 type: str
-                description: Deprecated, please rename it to _dynamic_server.
-            addr-mode:
+                description: Dynamic server.
+            addr_mode:
+                aliases: ['addr-mode']
                 type: str
-                description: Deprecated, please rename it to addr_mode. Address mode
+                description: Address mode
                 choices:
                     - 'ipv4'
                     - 'ipv6'
             diffservcode:
                 type: str
                 description: Differentiated services code point
-            dns-match-ip:
+            dns_match_ip:
+                aliases: ['dns-match-ip']
                 type: str
-                description: Deprecated, please rename it to dns_match_ip. Response IP expected from DNS server if the protocol is DNS.
-            dns-request-domain:
+                description: Response IP expected from DNS server if the protocol is DNS.
+            dns_request_domain:
+                aliases: ['dns-request-domain']
                 type: str
-                description: Deprecated, please rename it to dns_request_domain. Fully qualified domain name to resolve for the DNS probe.
+                description: Fully qualified domain name to resolve for the DNS probe.
             failtime:
                 type: int
                 description: Number of failures before server is considered lost
-            ftp-file:
+            ftp_file:
+                aliases: ['ftp-file']
                 type: str
-                description: Deprecated, please rename it to ftp_file. Full path and file name on the FTP server to download for FTP health-check to probe.
-            ftp-mode:
+                description: Full path and file name on the FTP server to download for FTP health-check to probe.
+            ftp_mode:
+                aliases: ['ftp-mode']
                 type: str
-                description: Deprecated, please rename it to ftp_mode. FTP mode.
+                description: FTP mode.
                 choices:
                     - 'passive'
                     - 'port'
-            ha-priority:
+            ha_priority:
+                aliases: ['ha-priority']
                 type: int
-                description: Deprecated, please rename it to ha_priority. HA election priority
-            http-agent:
+                description: HA election priority
+            http_agent:
+                aliases: ['http-agent']
                 type: str
-                description: Deprecated, please rename it to http_agent. String in the http-agent field in the HTTP header.
-            http-get:
+                description: String in the http-agent field in the HTTP header.
+            http_get:
+                aliases: ['http-get']
                 type: str
-                description: Deprecated, please rename it to http_get. URL used to communicate with the server if the protocol if the protocol is HTTP.
-            http-match:
+                description: URL used to communicate with the server if the protocol if the protocol is HTTP.
+            http_match:
+                aliases: ['http-match']
                 type: str
-                description: Deprecated, please rename it to http_match. Response string expected from the server if the protocol is HTTP.
+                description: Response string expected from the server if the protocol is HTTP.
             interval:
                 type: int
                 description: Status check interval in milliseconds, or the time between attempting to connect to the server
@@ -145,27 +155,31 @@ options:
                 type: str
                 description: Status check or health check name.
                 required: true
-            packet-size:
+            packet_size:
+                aliases: ['packet-size']
                 type: int
-                description: Deprecated, please rename it to packet_size. Packet size of a twamp test session,
+                description: Packet size of a twamp test session,
             password:
                 type: raw
-                description: (list) No description.
+                description: (list) Twamp controller password in authentication mode
             port:
                 type: int
                 description: Port number used to communicate with the server over the selected protocol
-            probe-count:
+            probe_count:
+                aliases: ['probe-count']
                 type: int
-                description: Deprecated, please rename it to probe_count. Number of most recent probes that should be used to calculate latency and jitter
-            probe-packets:
+                description: Number of most recent probes that should be used to calculate latency and jitter
+            probe_packets:
+                aliases: ['probe-packets']
                 type: str
-                description: Deprecated, please rename it to probe_packets. Enable/disable transmission of probe packets.
+                description: Enable/disable transmission of probe packets.
                 choices:
                     - 'disable'
                     - 'enable'
-            probe-timeout:
+            probe_timeout:
+                aliases: ['probe-timeout']
                 type: int
-                description: Deprecated, please rename it to probe_timeout. Time to wait before a probe packet is considered lost
+                description: Time to wait before a probe packet is considered lost
             protocol:
                 type: str
                 description: Protocol used to determine if the FortiGate can communicate with the server.
@@ -180,116 +194,139 @@ options:
                     - 'tcp-connect'
                     - 'ftp'
                     - 'https'
-            quality-measured-method:
+            quality_measured_method:
+                aliases: ['quality-measured-method']
                 type: str
-                description: Deprecated, please rename it to quality_measured_method. Method to measure the quality of tcp-connect.
+                description: Method to measure the quality of tcp-connect.
                 choices:
                     - 'half-close'
                     - 'half-open'
             recoverytime:
                 type: int
                 description: Number of successful responses received before server is considered recovered
-            security-mode:
+            security_mode:
+                aliases: ['security-mode']
                 type: str
-                description: Deprecated, please rename it to security_mode. Twamp controller security mode.
+                description: Twamp controller security mode.
                 choices:
                     - 'none'
                     - 'authentication'
             server:
                 type: raw
-                description: (list) No description.
+                description: (list) IP address or FQDN name of the server.
             sla:
                 type: list
                 elements: dict
-                description: No description.
+                description: Sla.
                 suboptions:
                     id:
                         type: int
                         description: SLA ID.
-                    jitter-threshold:
+                    jitter_threshold:
+                        aliases: ['jitter-threshold']
                         type: int
-                        description: Deprecated, please rename it to jitter_threshold. Jitter for SLA to make decision in milliseconds.
-                    latency-threshold:
+                        description: Jitter for SLA to make decision in milliseconds.
+                    latency_threshold:
+                        aliases: ['latency-threshold']
                         type: int
-                        description: Deprecated, please rename it to latency_threshold. Latency for SLA to make decision in milliseconds.
-                    link-cost-factor:
+                        description: Latency for SLA to make decision in milliseconds.
+                    link_cost_factor:
+                        aliases: ['link-cost-factor']
                         type: list
                         elements: str
-                        description: Deprecated, please rename it to link_cost_factor.
+                        description: Criteria on which to base link selection.
                         choices:
                             - 'latency'
                             - 'jitter'
                             - 'packet-loss'
                             - 'mos'
-                    packetloss-threshold:
+                            - 'remote'
+                    packetloss_threshold:
+                        aliases: ['packetloss-threshold']
                         type: int
-                        description: Deprecated, please rename it to packetloss_threshold. Packet loss for SLA to make decision in percentage.
-                    mos-threshold:
+                        description: Packet loss for SLA to make decision in percentage.
+                    mos_threshold:
+                        aliases: ['mos-threshold']
                         type: str
-                        description: Deprecated, please rename it to mos_threshold. Minimum Mean Opinion Score for SLA to be marked as pass.
-                    priority-in-sla:
+                        description: Minimum Mean Opinion Score for SLA to be marked as pass.
+                    priority_in_sla:
+                        aliases: ['priority-in-sla']
                         type: int
-                        description: Deprecated, please rename it to priority_in_sla. Value to be distributed into routing table when in-sla
-                    priority-out-sla:
+                        description: Value to be distributed into routing table when in-sla
+                    priority_out_sla:
+                        aliases: ['priority-out-sla']
                         type: int
-                        description: Deprecated, please rename it to priority_out_sla. Value to be distributed into routing table when out-sla
-            sla-fail-log-period:
+                        description: Value to be distributed into routing table when out-sla
+            sla_fail_log_period:
+                aliases: ['sla-fail-log-period']
                 type: int
-                description: Deprecated, please rename it to sla_fail_log_period. Time interval in seconds that SLA fail log messages will be generated
-            sla-pass-log-period:
+                description: Time interval in seconds that SLA fail log messages will be generated
+            sla_pass_log_period:
+                aliases: ['sla-pass-log-period']
                 type: int
-                description: Deprecated, please rename it to sla_pass_log_period. Time interval in seconds that SLA pass log messages will be generated
-            system-dns:
+                description: Time interval in seconds that SLA pass log messages will be generated
+            system_dns:
+                aliases: ['system-dns']
                 type: str
-                description: Deprecated, please rename it to system_dns. Enable/disable system DNS as the probe server.
+                description: Enable/disable system DNS as the probe server.
                 choices:
                     - 'disable'
                     - 'enable'
-            threshold-alert-jitter:
+            threshold_alert_jitter:
+                aliases: ['threshold-alert-jitter']
                 type: int
-                description: Deprecated, please rename it to threshold_alert_jitter. Alert threshold for jitter
-            threshold-alert-latency:
+                description: Alert threshold for jitter
+            threshold_alert_latency:
+                aliases: ['threshold-alert-latency']
                 type: int
-                description: Deprecated, please rename it to threshold_alert_latency. Alert threshold for latency
-            threshold-alert-packetloss:
+                description: Alert threshold for latency
+            threshold_alert_packetloss:
+                aliases: ['threshold-alert-packetloss']
                 type: int
-                description: Deprecated, please rename it to threshold_alert_packetloss. Alert threshold for packet loss
-            threshold-warning-jitter:
+                description: Alert threshold for packet loss
+            threshold_warning_jitter:
+                aliases: ['threshold-warning-jitter']
                 type: int
-                description: Deprecated, please rename it to threshold_warning_jitter. Warning threshold for jitter
-            threshold-warning-latency:
+                description: Warning threshold for jitter
+            threshold_warning_latency:
+                aliases: ['threshold-warning-latency']
                 type: int
-                description: Deprecated, please rename it to threshold_warning_latency. Warning threshold for latency
-            threshold-warning-packetloss:
+                description: Warning threshold for latency
+            threshold_warning_packetloss:
+                aliases: ['threshold-warning-packetloss']
                 type: int
-                description: Deprecated, please rename it to threshold_warning_packetloss. Warning threshold for packet loss
-            update-cascade-interface:
+                description: Warning threshold for packet loss
+            update_cascade_interface:
+                aliases: ['update-cascade-interface']
                 type: str
-                description: Deprecated, please rename it to update_cascade_interface. Enable/disable update cascade interface.
+                description: Enable/disable update cascade interface.
                 choices:
                     - 'disable'
                     - 'enable'
-            update-static-route:
+            update_static_route:
+                aliases: ['update-static-route']
                 type: str
-                description: Deprecated, please rename it to update_static_route. Enable/disable updating the static route.
+                description: Enable/disable updating the static route.
                 choices:
                     - 'disable'
                     - 'enable'
             user:
                 type: str
                 description: The user name to access probe server.
-            detect-mode:
+            detect_mode:
+                aliases: ['detect-mode']
                 type: str
-                description: Deprecated, please rename it to detect_mode. The mode determining how to detect the server.
+                description: The mode determining how to detect the server.
                 choices:
                     - 'active'
                     - 'passive'
                     - 'prefer-passive'
                     - 'remote'
                     - 'agent-based'
-            mos-codec:
+            mos_codec:
+                aliases: ['mos-codec']
                 type: str
-                description: Deprecated, please rename it to mos_codec. Codec to use for MOS calculation
+                description: Codec to use for MOS calculation
                 choices:
                     - 'g711'
                     - 'g722'
@@ -300,27 +337,49 @@ options:
             vrf:
                 type: int
                 description: Virtual Routing Forwarding ID.
-            embed-measured-health:
+            embed_measured_health:
+                aliases: ['embed-measured-health']
                 type: str
-                description: Deprecated, please rename it to embed_measured_health. Enable/disable embedding measured health information.
+                description: Enable/disable embedding measured health information.
                 choices:
                     - 'disable'
                     - 'enable'
-            sla-id-redistribute:
+            sla_id_redistribute:
+                aliases: ['sla-id-redistribute']
                 type: int
-                description: Deprecated, please rename it to sla_id_redistribute. Select the ID from the SLA sub-table.
-            class-id:
+                description: Select the ID from the SLA sub-table.
+            class_id:
+                aliases: ['class-id']
                 type: str
-                description: Deprecated, please rename it to class_id. Traffic class ID.
+                description: Traffic class ID.
             source6:
                 type: str
                 description: Source IPv6 addressused in the health-check packet to server.
+            fortiguard:
+                type: str
+                description: Enable/disable use of FortiGuard predefined server.
+                choices:
+                    - 'disable'
+                    - 'enable'
+            fortiguard_name:
+                aliases: ['fortiguard-name']
+                type: raw
+                description: (list) Predefined health-check target name.
+            agent_probe_timeout:
+                aliases: ['agent-probe-timeout']
+                type: int
+                description: Time to wait before a probe packet is considered lost when detect-mode is agent
+            remote_probe_timeout:
+                aliases: ['remote-probe-timeout']
+                type: int
+                description: Time to wait before a probe packet is considered lost when detect-mode is remote
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -329,74 +388,78 @@ EXAMPLES = '''
     - name: SD-WAN status checking or health checking.
       fortinet.fortimanager.fmgr_wanprof_system_sdwan_healthcheck:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         wanprof: <your own value>
         state: present # <value in [present, absent]>
         wanprof_system_sdwan_healthcheck:
-          _dynamic_server: <string>
-          addr_mode: <value in [ipv4, ipv6]>
-          diffservcode: <string>
-          dns_match_ip: <string>
-          dns_request_domain: <string>
-          failtime: <integer>
-          ftp_file: <string>
-          ftp_mode: <value in [passive, port]>
-          ha_priority: <integer>
-          http_agent: <string>
-          http_get: <string>
-          http_match: <string>
-          interval: <integer>
-          members: <list or string>
-          name: <string>
-          packet_size: <integer>
-          password: <list or string>
-          port: <integer>
-          probe_count: <integer>
-          probe_packets: <value in [disable, enable]>
-          probe_timeout: <integer>
-          protocol: <value in [ping, tcp-echo, udp-echo, ...]>
-          quality_measured_method: <value in [half-close, half-open]>
-          recoverytime: <integer>
-          security_mode: <value in [none, authentication]>
-          server: <list or string>
-          sla:
-            -
-              id: <integer>
-              jitter_threshold: <integer>
-              latency_threshold: <integer>
-              link_cost_factor:
-                - latency
-                - jitter
-                - packet-loss
-                - mos
-              packetloss_threshold: <integer>
-              mos_threshold: <string>
-              priority_in_sla: <integer>
-              priority_out_sla: <integer>
-          sla_fail_log_period: <integer>
-          sla_pass_log_period: <integer>
-          system_dns: <value in [disable, enable]>
-          threshold_alert_jitter: <integer>
-          threshold_alert_latency: <integer>
-          threshold_alert_packetloss: <integer>
-          threshold_warning_jitter: <integer>
-          threshold_warning_latency: <integer>
-          threshold_warning_packetloss: <integer>
-          update_cascade_interface: <value in [disable, enable]>
-          update_static_route: <value in [disable, enable]>
-          user: <string>
-          detect_mode: <value in [active, passive, prefer-passive, ...]>
-          mos_codec: <value in [g711, g722, g729]>
-          source: <string>
-          vrf: <integer>
-          embed_measured_health: <value in [disable, enable]>
-          sla_id_redistribute: <integer>
-          class_id: <string>
-          source6: <string>
+          name: "your value" # Required variable, string
+          # _dynamic_server: <string>
+          # addr_mode: <value in [ipv4, ipv6]>
+          # diffservcode: <string>
+          # dns_match_ip: <string>
+          # dns_request_domain: <string>
+          # failtime: <integer>
+          # ftp_file: <string>
+          # ftp_mode: <value in [passive, port]>
+          # ha_priority: <integer>
+          # http_agent: <string>
+          # http_get: <string>
+          # http_match: <string>
+          # interval: <integer>
+          # members: <list or string>
+          # packet_size: <integer>
+          # password: <list or string>
+          # port: <integer>
+          # probe_count: <integer>
+          # probe_packets: <value in [disable, enable]>
+          # probe_timeout: <integer>
+          # protocol: <value in [ping, tcp-echo, udp-echo, ...]>
+          # quality_measured_method: <value in [half-close, half-open]>
+          # recoverytime: <integer>
+          # security_mode: <value in [none, authentication]>
+          # server: <list or string>
+          # sla:
+          #   - id: <integer>
+          #     jitter_threshold: <integer>
+          #     latency_threshold: <integer>
+          #     link_cost_factor:
+          #       - "latency"
+          #       - "jitter"
+          #       - "packet-loss"
+          #       - "mos"
+          #       - "remote"
+          #     packetloss_threshold: <integer>
+          #     mos_threshold: <string>
+          #     priority_in_sla: <integer>
+          #     priority_out_sla: <integer>
+          # sla_fail_log_period: <integer>
+          # sla_pass_log_period: <integer>
+          # system_dns: <value in [disable, enable]>
+          # threshold_alert_jitter: <integer>
+          # threshold_alert_latency: <integer>
+          # threshold_alert_packetloss: <integer>
+          # threshold_warning_jitter: <integer>
+          # threshold_warning_latency: <integer>
+          # threshold_warning_packetloss: <integer>
+          # update_cascade_interface: <value in [disable, enable]>
+          # update_static_route: <value in [disable, enable]>
+          # user: <string>
+          # detect_mode: <value in [active, passive, prefer-passive, ...]>
+          # mos_codec: <value in [g711, g722, g729]>
+          # source: <string>
+          # vrf: <integer>
+          # embed_measured_health: <value in [disable, enable]>
+          # sla_id_redistribute: <integer>
+          # class_id: <string>
+          # source6: <string>
+          # fortiguard: <value in [disable, enable]>
+          # fortiguard_name: <list or string>
+          # agent_probe_timeout: <integer>
+          # remote_probe_timeout: <integer>
 '''
 
 RETURN = '''
@@ -440,21 +503,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/wanprof/{wanprof}/system/sdwan/health-check'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/wanprof/{wanprof}/system/sdwan/health-check/{health-check}'
-    ]
-
     url_params = ['adom', 'wanprof']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -464,7 +520,7 @@ def main():
             'type': 'dict',
             'v_range': [['6.4.1', '']],
             'options': {
-                '_dynamic-server': {'v_range': [['6.4.1', '6.4.13']], 'type': 'str'},
+                '_dynamic-server': {'v_range': [['6.4.1', '6.4.15']], 'type': 'str'},
                 'addr-mode': {'v_range': [['6.4.1', '']], 'choices': ['ipv4', 'ipv6'], 'type': 'str'},
                 'diffservcode': {'v_range': [['6.4.1', '']], 'type': 'str'},
                 'dns-match-ip': {'v_range': [['6.4.2', '']], 'type': 'str'},
@@ -504,7 +560,7 @@ def main():
                         'link-cost-factor': {
                             'v_range': [['6.4.1', '']],
                             'type': 'list',
-                            'choices': ['latency', 'jitter', 'packet-loss', 'mos'],
+                            'choices': ['latency', 'jitter', 'packet-loss', 'mos', 'remote'],
                             'elements': 'str'
                         },
                         'packetloss-threshold': {'v_range': [['6.4.1', '']], 'type': 'int'},
@@ -533,9 +589,12 @@ def main():
                 'embed-measured-health': {'v_range': [['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'sla-id-redistribute': {'v_range': [['7.2.1', '']], 'type': 'int'},
                 'class-id': {'v_range': [['7.4.0', '']], 'type': 'str'},
-                'source6': {'v_range': [['7.4.0', '']], 'type': 'str'}
+                'source6': {'v_range': [['7.4.0', '']], 'type': 'str'},
+                'fortiguard': {'v_range': [['7.6.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'fortiguard-name': {'v_range': [['7.6.2', '']], 'type': 'raw'},
+                'agent-probe-timeout': {'v_range': [['7.6.3', '']], 'type': 'int'},
+                'remote-probe-timeout': {'v_range': [['7.6.3', '']], 'type': 'int'}
             }
-
         }
     }
 
@@ -544,17 +603,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'wanprof_system_sdwan_healthcheck'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
