@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -142,6 +145,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -150,8 +154,8 @@ EXAMPLES = '''
     - name: File filter entries.
       fortinet.fortimanager.fmgr_webfilter_profile_filefilter_entries:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -225,18 +229,19 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'profile': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'webfilter_profile_filefilter_entries': {
             'type': 'dict',
-            'v_range': [['6.2.0', '']],
+            'v_range': [['6.2.0', '7.6.2']],
             'options': {
-                'action': {'v_range': [['6.2.0', '']], 'choices': ['log', 'block'], 'type': 'str'},
-                'comment': {'v_range': [['6.2.0', '']], 'type': 'str'},
-                'direction': {'v_range': [['6.2.0', '']], 'choices': ['any', 'incoming', 'outgoing'], 'type': 'str'},
+                'action': {'v_range': [['6.2.0', '7.6.2']], 'choices': ['log', 'block'], 'type': 'str'},
+                'comment': {'v_range': [['6.2.0', '7.6.2']], 'type': 'str'},
+                'direction': {'v_range': [['6.2.0', '7.6.2']], 'choices': ['any', 'incoming', 'outgoing'], 'type': 'str'},
                 'encryption': {'v_range': [['6.2.0', '7.2.0']], 'choices': ['any', 'yes'], 'type': 'str'},
-                'file-type': {'v_range': [['6.2.0', '']], 'type': 'raw'},
-                'filter': {'v_range': [['6.2.0', '']], 'type': 'str'},
-                'password-protected': {'v_range': [['6.2.1', '']], 'choices': ['any', 'yes'], 'type': 'str'},
-                'protocol': {'v_range': [['6.2.0', '']], 'type': 'list', 'choices': ['http', 'ftp'], 'elements': 'str'}
+                'file-type': {'v_range': [['6.2.0', '7.6.2']], 'type': 'raw'},
+                'filter': {'v_range': [['6.2.0', '7.6.2']], 'type': 'str'},
+                'password-protected': {'v_range': [['6.2.1', '7.6.2']], 'choices': ['any', 'yes'], 'type': 'str'},
+                'protocol': {'v_range': [['6.2.0', '7.6.2']], 'type': 'list', 'choices': ['http', 'ftp'], 'elements': 'str'}
             }
         }
     }
