@@ -1,3 +1,5 @@
+import time
+
 try:
     from ..common.ansible_common import (
         convert_block_capacity,
@@ -86,6 +88,7 @@ class VSPVolumeReconciler:
         self.port_prov = VSPStoragePortProvisioner(self.connection_info)
         self.nvme_provisioner = VSPNvmeProvisioner(self.connection_info, self.serial)
         self.hg_prov = VSPHostGroupProvisioner(self.connection_info)
+        self.snapshots = None
 
     @log_entry_exit
     def volume_reconcile(self, state: str, spec: CreateVolumeSpec):
@@ -105,8 +108,8 @@ class VSPVolumeReconciler:
                 return "NVM subsystem updated successfully."
 
             volume = None
+            new_vol = False
             if spec.ldev_id:
-                # volume = self.provisioner.get_volume_by_ldev(100)
                 volume = self.provisioner.get_volume_by_ldev(spec.ldev_id)
                 logger.writeDebug("RC:sng20241205 volume={}", volume)
 
@@ -116,16 +119,17 @@ class VSPVolumeReconciler:
                     self.update_volume_name(spec.ldev_id, spec.name)
                 else:
                     self.update_volume_name(spec.ldev_id, None)
-            else:
-                # sng20241202 update_volume
-                self.update_volume(volume, spec)
 
-            vol = self.provisioner.get_volume_by_ldev(spec.ldev_id)
+                volume = self.provisioner.get_volume_by_ldev(spec.ldev_id)
+                new_vol = True
+
+            self.update_volume(volume, spec, new_vol)
 
             # Check if the ldev is a command device
-            if vol.attributes and "CMD" in vol.attributes:
-                self.provisioner.fill_cmd_device_info(vol)
+            if volume.attributes and "CMD" in volume.attributes:
+                self.provisioner.fill_cmd_device_info(volume)
 
+            additional_change = False
             if spec.should_shred_volume_enable:
                 unused = self.provisioner.shredding_volume(
                     spec.ldev_id, spec.should_shred_volume_enable
@@ -135,7 +139,72 @@ class VSPVolumeReconciler:
             if spec.qos_settings:
                 self.provisioner.change_qos_settings(spec.ldev_id, spec.qos_settings)
                 logger.writeInfo("RC:volume_reconcile:qos_settings finished")
-            return self.get_volume_detail_info(vol)
+                self.connection_info.changed = True
+                additional_change = True
+
+            if spec.mp_blade_id is not None and spec.mp_blade_id != volume.mpBladeId:
+                self.provisioner.change_mp_blade(spec.ldev_id, spec.mp_blade_id)
+                self.connection_info.changed = True
+                additional_change = True
+
+            if spec.clpr_id is not None and spec.clpr_id != volume.clprId:
+                self.provisioner.assign_ldev_to_clpr(spec.ldev_id, spec.clpr_id)
+                self.connection_info.changed = True
+                additional_change = True
+
+            if spec.should_reclaim_zero_pages:
+                self.provisioner.reclaim_zero_pages(spec.ldev_id)
+                logger.writeInfo("RC:volume_reconcile:reclaim_zero_pages finished")
+                self.connection_info.changed = True
+                additional_change = True
+
+            # Keep this logic always at the end of the volume creation
+            if spec.should_format_volume:
+                if volume.status.upper() != VolumePayloadConst.BLOCK:
+                    logger.writeDebug(
+                        "RC:volume_reconcile:formatting volume as it is not in BLOCK state"
+                    )
+                    self.provisioner.change_volume_status(spec.ldev_id, True)
+
+                force_format = (
+                    True
+                    if volume.dataReductionMode
+                    and volume.dataReductionMode.lower() != VolumePayloadConst.DISABLED
+                    else False
+                )
+                try:
+                    self.provisioner.format_volume(
+                        spec.ldev_id,
+                        force_format=force_format,
+                        format_type=spec.format_type,
+                    )
+                except Exception as e:
+                    if "Timeout Error!" in str(e):
+                        spec.is_task_timeout = True
+                    else:
+                        self.provisioner.change_volume_status(spec.ldev_id, False)
+                        raise e
+
+                logger.writeInfo("RC:volume_reconcile:format volume finished")
+                self.connection_info.changed = True
+
+            if additional_change:
+                volume = self.provisioner.get_volume_by_ldev(spec.ldev_id)
+
+            if new_vol:
+                if spec and hasattr(spec, "comment") is not None:
+                    spec.comment = "Volume created successfully."
+            create_qos_settings = True if spec.qos_settings else False
+            return self.get_volume_detail_info(volume, create_qos_setting=create_qos_settings)
+
+        elif state == StateValue.ASSIGN_VIRTUAL_LDEV:
+            if spec.ldev_id is None and spec.vldev_id is None:
+                raise ValueError(VSPVolValidationMsg.BOTH_LDEV_VLDEV_ID_REQD.value)
+            volume = self.provisioner.get_volume_by_ldev(spec.ldev_id)
+            logger.writeDebug("RC:volume_reconcile:state=absent:volume={}", volume)
+            changed = self.provisioner.change_volume_settings_vldev(spec, volume)
+            self.connection_info.changed = changed
+            return self.get_volume_detail_info(volume)
 
         elif state == StateValue.ABSENT:
             volume = self.provisioner.get_volume_by_ldev(spec.ldev_id)
@@ -168,8 +237,13 @@ class VSPVolumeReconciler:
             self.process_update_nvme(found, spec)
 
     @log_entry_exit
-    def update_volume(self, volume_data: VSPVolumeInfo, spec: CreateVolumeSpec):
+    def update_volume(
+        self, volume_data: VSPVolumeInfo, spec: CreateVolumeSpec, new_vol: bool
+    ):
 
+        if new_vol:
+            spec.name = None
+            spec.capacity_saving = None
         # sng20241205 VLDEVID_META_RSRC
         logger.writeDebug("RC: sng20241205 volume_data={}", volume_data)
         logger.writeDebug("RC: sng20241205 spec.vldev_id={}", spec.vldev_id)
@@ -214,16 +288,27 @@ class VSPVolumeReconciler:
                 self.connection_info.changed = True
             elif expand_val < 0:
                 raise ValueError(VSPVolValidationMsg.VALID_SIZE.value)
+        if (
+            spec.capacity_saving is not None
+            and spec.capacity_saving == volume_data.dataReductionMode
+        ):
+            spec.capacity_saving = None
+        if spec.name is not None and spec.name == volume_data.label:
+            spec.name = None
 
         # update the volume by comparing the existing details
         if (
-            spec.capacity_saving
-            and spec.capacity_saving != volume_data.dataReductionMode
-        ) or (spec.name and spec.name != volume_data.label):
+            (spec.capacity_saving is not None)
+            or (spec.name is not None)
+            or spec.is_alua_enabled is not None
+            or spec.is_relocation_enabled is not None
+            or spec.data_reduction_process_mode is not None
+            or spec.is_compression_acceleration_enabled is not None
+            or spec.is_full_allocation_enabled is not None
+        ):
             self.provisioner.change_volume_settings(
-                volume_data.ldevId, spec.name, spec.capacity_saving
+                volume_data.ldevId, spec.name, spec.capacity_saving, spec
             )
-            self.connection_info.changed = True
 
         # sng20241202 update change_volume_settings_tier
         self.provisioner.change_volume_settings_tier(spec, volume_data.ldevId)
@@ -233,7 +318,7 @@ class VSPVolumeReconciler:
 
         if found:
             self.process_update_nvme(found, spec)
-
+        logger.writeDebug("RC:update_volume:changed={}", self.connection_info.changed)
         return volume_data.ldevId
 
     @log_entry_exit
@@ -620,12 +705,21 @@ class VSPVolumeReconciler:
     @log_entry_exit
     def create_volume(self, spec: CreateVolumeSpec):
         logger.writeDebug("RC:create_volume:spec={}", spec)
-        if spec.pool_id is not None and spec.parity_group:
+        if spec.pool_id is not None and (
+            spec.parity_group or spec.external_parity_group
+        ):
             raise ValueError(VSPVolValidationMsg.POOL_ID_PARITY_GROUP.value)
-        if spec.parity_group and spec.tiering_policy:
+        if spec.parity_group and spec.external_parity_group:
+            raise ValueError(VSPVolValidationMsg.BOTH_PARITY_GROUPS_SPECIFIED.value)
+        if (spec.parity_group or spec.external_parity_group) and spec.tiering_policy:
             raise ValueError(VSPVolValidationMsg.BOTH_PARITY_GRP_TIERING.value)
+
         self.validate_tiering_policy(spec)
-        if spec.pool_id is None and not spec.parity_group:
+        if (
+            spec.pool_id is None
+            and not spec.parity_group
+            and not spec.external_parity_group
+        ):
             raise ValueError(VSPVolValidationMsg.NOT_POOL_ID_OR_PARITY_ID.value)
         if not spec.size:
             raise ValueError(VSPVolValidationMsg.SIZE_REQUIRED.value)
@@ -657,8 +751,9 @@ class VSPVolumeReconciler:
         return volume_created
 
     @log_entry_exit
-    def get_snapshot_list_for_volume(self, volume, snapshots):
+    def get_snapshot_list_for_volume(self, volume, snapshots=None):
         retList = []
+        snapshots = self.get_all_snapshots() if snapshots is None else snapshots
         if snapshots:
             for x in snapshots:
                 if x["pvolLdevId"] == volume.ldevId or x["svolLdevId"] == volume.ldevId:
@@ -670,9 +765,14 @@ class VSPVolumeReconciler:
 
     @log_entry_exit
     def get_all_snapshots(self):
-        snapshot_prov = VSPHtiSnapshotProvisioner(self.connection_info)
-        snapshots = snapshot_prov.get_snapshot_facts()
-        return snapshots
+        if self.snapshots is None:
+            snapshot_prov = VSPHtiSnapshotProvisioner(self.connection_info)
+            start_time = time.time()
+            self.snapshots = snapshot_prov.get_snapshot_facts()
+            end_time = time.time()
+            elapsed_time = float(f"{end_time - start_time:.2f}")
+            logger.writeDebug("RC:time taken for get_all_snapshots={}", elapsed_time)
+        return self.snapshots
 
     @log_entry_exit
     def get_nvm_subsystem_for_ldev(self, ldev_id):
@@ -723,16 +823,75 @@ class VSPVolumeReconciler:
         return result_list
 
     @log_entry_exit
-    def get_volume_detail_info(self, volume, all_snapshots=None, single_vol=True):
-        if all_snapshots:
-            snapshots = self.get_snapshot_list_for_volume(volume, all_snapshots)
-            volume.snapshots = snapshots
-        volume.isEncryptionEnabled = self.is_encryption_enabled_on_volume(volume)
-        hg_iscsi_tar_info = self.get_hostgroup_and_iscsi_target_info(volume, single_vol)
+    def get_volumes_with_hg_iscsi(self, volumes):
+        retList = []
+        if volumes:
+            for volume in volumes:
+                hg_iscsi_tar_info = self.get_hostgroup_and_iscsi_target_info(volume)
+                hostgroups = hg_iscsi_tar_info["hostgroups"]
+                iscsi_targets = hg_iscsi_tar_info["iscsiTargets"]
+                volume.hostgroups = hostgroups
+                volume.iscsiTargets = iscsi_targets
+                retList.append(volume)
+        return VSPVolumesInfo(data=retList)
+
+    @log_entry_exit
+    def get_volumes_detail_for_spec(self, volumes, spec):
+        retList = []
+        if volumes:
+            for volume in volumes:
+                new_volume = self.get_volume_detail_for_spec(volume, spec)
+                retList.append(new_volume)
+        return VSPVolumesInfo(data=retList)
+
+    @log_entry_exit
+    def get_volume_detail_for_spec(self, volume, spec):
+        # host group and iSCSI target info are always included
+        hg_iscsi_tar_info = self.get_hostgroup_and_iscsi_target_info(volume)
         hostgroups = hg_iscsi_tar_info["hostgroups"]
         iscsi_targets = hg_iscsi_tar_info["iscsiTargets"]
         volume.hostgroups = hostgroups
         volume.iscsiTargets = iscsi_targets
+
+        if spec.is_detailed is not None and spec.is_detailed is True:
+            logger.writeDebug("RC:get_volume_detail_with_spec:spec={}", spec)
+            return self.get_volume_detail_info(volume, self.get_all_snapshots())
+        else:
+            logger.writeDebug("RC:get_volume_detail_with_spec:else:spec={}", spec)
+            if spec.query:
+                if "cmd_device_settings" in spec.query:
+                    if volume.attributes and "CMD" in volume.attributes:
+                        self.provisioner.fill_cmd_device_info(volume)
+                if "encryption_settings" in spec.query:
+                    volume.isEncryptionEnabled = self.is_encryption_enabled_on_volume(
+                        volume
+                    )
+                if "nvm_subsystem_info" in spec.query:
+                    if volume.nvmSubsystemId:
+                        nvm_subsystems = self.get_nvm_subsystem_info(volume)
+                        logger.writeDebug(
+                            "RC:get_volume_detail_with_spec:nvm_subsystem = {}",
+                            nvm_subsystems,
+                        )
+                        volume.nvmSubsystems = nvm_subsystems
+                if "qos_settings" in spec.query:
+                    qos_settings = self.provisioner.get_qos_settings(volume.ldevId)
+                    if qos_settings:
+                        volume.qosSettings = qos_settings
+                if "snapshots_info" in spec.query:
+                    volume.snapshots = self.get_snapshot_list_for_volume(volume)
+
+        return volume
+
+    @log_entry_exit
+    def get_volume_detail_info(self, volume, all_snapshots=None, single_vol=True, create_qos_setting=True):
+        logger.writeDebug("RC:get_volume_detail_info:volume={}", volume)
+        if all_snapshots:
+            snapshots = self.get_snapshot_list_for_volume(volume, all_snapshots)
+            volume.snapshots = snapshots
+
+        volume.isEncryptionEnabled = self.is_encryption_enabled_on_volume(volume)
+
         if volume.nvmSubsystemId:
             nvm_subsystems = self.get_nvm_subsystem_info(volume)
             logger.writeDebug(
@@ -740,17 +899,21 @@ class VSPVolumeReconciler:
             )
             volume.nvmSubsystems = nvm_subsystems
 
-        qos_settings = self.provisioner.get_qos_settings(volume.ldevId)
-        if qos_settings:
-            volume.qosSettings = qos_settings
+        qos_settings = None
+        if create_qos_setting:
+            qos_settings = self.provisioner.get_qos_settings(volume.ldevId)
+
+        volume.qosSettings = qos_settings
 
         # Check if the ldev is a command device
         # This get call is needed for newly created cmd device
-        check_vol = self.provisioner.get_volume_by_ldev(volume.ldevId)
-        if check_vol.attributes and "CMD" in check_vol.attributes:
-            volume.attributes = check_vol.attributes
-            self.provisioner.fill_cmd_device_info(volume)
+        # check_vol = self.provisioner.get_volume_by_ldev(volume.ldevId)
+        # if check_vol.attributes and "CMD" in check_vol.attributes:
+        #     volume.attributes = check_vol.attributes
+        #     self.provisioner.fill_cmd_device_info(volume)
 
+        if volume.attributes and "CMD" in volume.attributes:
+            self.provisioner.fill_cmd_device_info(volume)
         return volume
 
     @log_entry_exit
@@ -846,17 +1009,28 @@ class VSPVolumeReconciler:
     @log_entry_exit
     def get_volumes(self, get_volume_spec: VolumeFactSpec):
         logger.writeDebug("RC:get_volumes:spec={}", get_volume_spec)
-        if get_volume_spec.ldev_id:
+
+        if get_volume_spec.query and "free_ldev_id" in get_volume_spec.query:
+            return self.provisioner.get_free_ldevs_from_meta(
+                get_volume_spec.count,
+                get_volume_spec.start_ldev_id,
+                get_volume_spec.end_ldev_id,
+                get_volume_spec.resource_group_id,
+            )
+
+        if get_volume_spec.ldev_id is not None:
             # new_volume = None
             volume = self.provisioner.get_volume_by_ldev(get_volume_spec.ldev_id)
             if volume:
-                if (
-                    get_volume_spec.is_detailed is not None
-                    and get_volume_spec.is_detailed is True
-                ):
+                # if (
+                #     get_volume_spec.is_detailed is not None
+                #     and get_volume_spec.is_detailed is True
+                # ):
 
-                    all_snapshots = self.get_all_snapshots()
-                    volume = self.get_volume_detail_info(volume, all_snapshots)
+                #     all_snapshots = self.get_all_snapshots()
+                #     volume = self.get_volume_detail_info(volume, all_snapshots)
+                volume = self.get_volume_detail_for_spec(volume, get_volume_spec)
+                logger.writeDebug("RC:get_volumes:found volume={}", volume)
 
                 return VSPVolumesInfo(data=[volume])
 
@@ -869,7 +1043,12 @@ class VSPVolumeReconciler:
                 get_volume_spec.end_ldev_id - get_volume_spec.start_ldev_id + 1
             )
         volume_data = self.provisioner.get_volumes(
-            get_volume_spec.start_ldev_id, get_volume_spec.count
+            get_volume_spec.start_ldev_id,
+            get_volume_spec.count,
+            get_volume_spec.pool_id,
+            get_volume_spec.resource_group_id,
+            get_volume_spec.journal_id,
+            get_volume_spec.parity_group_id,
         )
 
         if get_volume_spec.end_ldev_id:
@@ -888,9 +1067,9 @@ class VSPVolumeReconciler:
             get_volume_spec.is_detailed is not None
             and get_volume_spec.is_detailed is True
         ):
-            return self.get_volumes_detail_info(volume_data.data)
+            return self.get_volumes_detail_for_spec(volume_data.data, get_volume_spec)
         else:
-            return volume_data
+            return self.get_volumes_with_hg_iscsi(volume_data.data)
 
     @log_entry_exit
     def generate_volume_name(self, ldev_id, label):
@@ -940,7 +1119,7 @@ class VSPVolumeReconciler:
             self.provisioner.delete_volume(ldev_id, force_execute)
             self.connection_info.changed = True
         except Exception as e:
-            logger.writeError(f"An error occurred in delete_volumne: {str(e)}")
+            logger.writeError(f"An error occurred in delete_volume: {str(e)}")
             raise ValueError(VSPVolValidationMsg.VOLUME_HAS_PATH.value)
 
     @log_entry_exit
@@ -1102,9 +1281,6 @@ class VolumeCommonPropertiesExtractor:
             "iscsi_targets": list,
             "snapshots": list,
             "nvm_subsystems": list,
-            "entitlement_status": str,
-            "partner_id": str,
-            "subscriber_id": str,
             "storage_serial_number": str,
             # sng20241202 tiering_policy extractor
             "tiering_policy": dict,
@@ -1122,6 +1298,13 @@ class VolumeCommonPropertiesExtractor:
             "is_device_group_definition_enabled": bool,
             "is_write_protected": bool,
             "is_write_protected_by_key": bool,
+            "is_compression_acceleration_enabled": bool,
+            "compression_acceleration_status": str,
+            "mp_blade_id": int,
+            "clpr_id": int,
+            "data_reduction_process_mode": str,
+            "is_relocation_enabled": bool,
+            "is_full_allocation_enabled": bool,
         }
 
         self.parameter_mapping = {
@@ -1259,8 +1442,6 @@ class VolumeCommonPropertiesExtractor:
                     logger.writeDebug(
                         "tieringProperties={}", response["tieringPropertiesDto"]
                     )
-                    logger.writeDebug("response_key={}", response_key)
-                    logger.writeDebug("key={}", key)
                     new_dict[key] = camel_to_snake_case_dict(response_key)
                     new_dict["tiering_policy"]["tier1_used_capacity_mb"] = new_dict[
                         "tiering_policy"
