@@ -20,36 +20,13 @@ version_added: '3.0.0'
 author:
   - Hitachi Vantara LTD (@hitachi-vantara)
 requirements:
-  - python >= 3.8
+  - python >= 3.9
 attributes:
   check_mode:
     description: Determines if the module should run in check mode.
     support: full
-options:
-  connection_info:
-    description: Information required to establish a connection to the storage system.
-    required: true
-    type: dict
-    suboptions:
-      address:
-        description: IP address or hostname of the storage system.
-        type: str
-        required: true
-      username:
-        description: Username for authentication.
-        type: str
-        required: true
-      password:
-        description: Password for authentication.
-        type: str
-        required: true
-      connection_type:
-        description: Type of connection to the storage system.
-        type: str
-        required: false
-        choices: ['direct']
-        default: 'direct'
-
+extends_documentation_fragment:
+  - hitachivantara.vspone_block.common.sdsb_connection_info
 """
 
 EXAMPLES = """
@@ -73,6 +50,10 @@ ansible_facts:
       description: The storage system information.
       type: dict
       contains:
+        api_version:
+          description: API version.
+          type: str
+          sample: "01.17.00.40"
         efficiency_data_reduction:
           description: Efficiency data reduction percentage.
           type: int
@@ -126,6 +107,10 @@ ansible_facts:
           description: Number of total volumes.
           type: int
           sample: 14
+        product_name:
+          description: API name.
+          type: str
+          sample: "Hitachi Virtual Storage Software Block REST API"
         total_efficiency:
           description: Total efficiency percentage.
           type: int
@@ -162,11 +147,10 @@ from ansible_collections.hitachivantara.vspone_block.plugins.module_utils.common
     validate_ansible_product_registration,
 )
 
-logger = Log()
-
 
 class SDSBStorageSystemFactManager:
     def __init__(self):
+        self.logger = Log()
         self.argument_spec = SDSBStorageSystemArguments().storage_system_fact()
         self.module = AnsibleModule(
             argument_spec=self.argument_spec,
@@ -178,6 +162,7 @@ class SDSBStorageSystemFactManager:
             self.module.fail_json(msg=str(e))
 
     def apply(self):
+        self.logger.writeInfo("=== Start of SDSB Storage System Facts ===")
         sdsb_storage_system_data = None
 
         registration_message = validate_ansible_product_registration()
@@ -188,11 +173,14 @@ class SDSBStorageSystemFactManager:
             )
 
         except Exception as e:
+            self.logger.writeException(e)
+            self.logger.writeInfo("=== End of SDSB Storage System Facts ===")
             self.module.fail_json(msg=str(e))
 
         data = {"storage_system": snake_case_storage_system_data}
         if registration_message:
             data["user_consent_required"] = registration_message
+        self.logger.writeInfo("=== End of SDSB Storage System Facts ===")
         self.module.exit_json(changed=False, ansible_facts=data)
 
     def direct_sdsb_storage_system_read(self):
