@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-# (c) 2018-2022, NetApp, Inc
+# (c) 2018-2025, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
@@ -14,7 +14,7 @@ short_description: NetApp ONTAP service processor network
 extends_documentation_fragment:
     - netapp.ontap.netapp.na_ontap
 version_added: 2.6.0
-author: NetApp Ansible Team (@carchi8py) <ng-ansibleteam@netapp.com>
+author: NetApp Ansible Team (@carchi8py) <ng-ansible-team@netapp.com>
 description:
   - Modify a ONTAP service processor network
 options:
@@ -75,16 +75,16 @@ options:
 '''
 
 EXAMPLES = """
-    - name: Modify Service Processor Network, enable dhcp.
-      netapp.ontap.na_ontap_service_processor_network:
-        state: present
-        address_type: ipv4
-        is_enabled: true
-        dhcp: v4
-        node: "{{ netapp_node }}"
-        username: "{{ netapp_username }}"
-        password: "{{ netapp_password }}"
-        hostname: "{{ netapp_hostname }}"
+- name: Modify Service Processor Network, enable dhcp.
+  netapp.ontap.na_ontap_service_processor_network:
+    state: present
+    address_type: ipv4
+    is_enabled: true
+    dhcp: v4
+    node: "{{ netapp_node }}"
+    username: "{{ netapp_username }}"
+    password: "{{ netapp_password }}"
+    hostname: "{{ netapp_hostname }}"
 """
 
 RETURN = """
@@ -362,8 +362,6 @@ class NetAppOntapServiceProcessorNetwork:
         """
         Run Module based on play book
         """
-        if not self.use_rest:
-            netapp_utils.ems_log_event_cserver("na_ontap_service_processor_network", self.server, self.module)
         current = self.get_service_processor_network()
         modify = self.na_helper.get_modified_attributes(current, self.parameters)
         if not current:
@@ -376,7 +374,8 @@ class NetAppOntapServiceProcessorNetwork:
             self.validate_rest(modify) if self.use_rest else self.validate_zapi(modify)
         if self.na_helper.changed and not self.module.check_mode:
             self.modify_service_processor_network(modify)
-        self.module.exit_json(changed=self.na_helper.changed)
+        result = netapp_utils.generate_result(self.na_helper.changed, modify=modify)
+        self.module.exit_json(**result)
 
 
 def main():
