@@ -205,6 +205,7 @@ options:
     - The group ownership for new files and directories in a file system
     type: str
     choices: [ 'creator', 'parent-directory' ]
+    default: creator
     version_added: "1.17.0"
 extends_documentation_fragment:
     - purestorage.flashblade.purestorage.fb
@@ -259,8 +260,8 @@ EXAMPLES = """
   purestorage.flashblade.purefb_fs:
     name: foo
     size: 2T
-    nfsv3 : false
-    nfsv4 : true
+    nfsv3: false
+    nfsv4: true
     user_quota: 10K
     group_quota: 25M
     nfs_rules: '10.21.200.0/24(ro)'
@@ -270,7 +271,8 @@ EXAMPLES = """
     smb: true
     state: present
     fb_url: 10.10.10.2
-    api_token: T-55a68eb5-c785-4720-a2ca-8b03903bf641"""
+    api_token: T-55a68eb5-c785-4720-a2ca-8b03903bf641
+"""
 
 RETURN = """
 """
@@ -374,13 +376,16 @@ def create_fs(module, blade):
                                 module.fail_json(
                                     msg="Cannot set access_control to smb or independent when SMB is not enabled."
                                 )
+                            if module.params["smb"] and not (
+                                module.params["nfsv3"] or module.params["nfsv4"]
+                            ):
+                                module.params["nfs_rules"] = ""
                             if module.params["safeguard_acls"] and (
                                 module.params["access_control"]
                                 in ["mode-bits", "independent"]
-                                or module.params["smb"]
                             ):
                                 module.fail_json(
-                                    msg="ACL Safeguarding cannot be enabled with SMB or if access_control is mode-bits or independent."
+                                    msg="ACL Safeguarding cannot be enabled if access_control is mode-bits or independent."
                                 )
                             fs_obj = FileSystem(
                                 name=module.params["name"],
@@ -596,9 +601,11 @@ def create_fs(module, blade):
 def modify_fs(module, blade):
     """Modify Filesystem"""
     changed = False
+    change_client = False
     change_export = False
     change_share = False
     change_ca = False
+    change_go = False
     mod_fs = False
     attr = {}
     if module.params["policy"] and module.params["policy_state"] == "present":
@@ -858,7 +865,6 @@ def modify_fs(module, blade):
                     )
                 )
     if SMB_POLICY_API_VERSION in api_version and module.params["client_policy"]:
-        change_client = False
         if (
             current_fs.smb.client_policy.name
             and current_fs.smb.client_policy.name != module.params["client_policy"]
@@ -883,7 +889,6 @@ def modify_fs(module, blade):
                     )
                 )
     if SMB_POLICY_API_VERSION in api_version and module.params["share_policy"]:
-        change_share = False
         if (
             current_fs.smb.share_policy.name
             and current_fs.smb.share_policy.name != module.params["share_policy"]
@@ -908,53 +913,56 @@ def modify_fs(module, blade):
                     )
                 )
     if CA_API_VERSION in api_version:
-        change_ca = False
         if (
             module.params["continuous_availability"]
-            != current_fs.continuous_availability_enabled
+            != current_fs.smb.continuous_availability_enabled
         ):
             change_ca = True
-            if not module.check_mode:
-                ca_attr = FileSystemPatch(
-                    smb=Smb(
-                        continuous_availability_enabled=module.params[
-                            "continuous_availability"
-                        ]
+        if not module.check_mode and change_ca:
+            ca_attr = FileSystemPatch(
+                smb=Smb(
+                    continuous_availability_enabled=module.params[
+                        "continuous_availability"
+                    ]
+                )
+            )
+            res = system.patch_file_systems(
+                names=[module.params["name"]], file_system=ca_attr
+            )
+            if res.status_code != 200:
+                module.fail_json(
+                    msg="Failed to modify continuous availability for "
+                    "filesystem {0}. Error: {1}".format(
+                        module.params["name"],
+                        res.errors[0].message,
                     )
                 )
-                res = system.patch_file_systems(
-                    names=[module.params["name"]], file_system=ca_attr
-                )
-                if res.status_code != 200:
-                    module.fail_json(
-                        msg="Failed to modify continuous availability for "
-                        "filesystem {0}. Error: {1}".format(
-                            module.params["name"],
-                            res.errors[0].message,
-                        )
-                    )
     if GOWNER_API_VERSION in api_version:
-        change_go = False
         if module.params["group_ownership"] != current_fs.group_ownership:
             change_go = True
-            if not module.check_mode:
-                go_attr = FileSystemPatch(
-                    group_ownership=module.params["group_ownership"]
-                )
-                res = system.patch_file_systems(
-                    names=[module.params["name"]], file_system=go_attr
-                )
-                if res.status_code != 200:
-                    module.fail_json(
-                        msg="Failed to modify group ownership for "
-                        "filesystem {0}. Error: {1}".format(
-                            module.params["name"],
-                            res.errors[0].message,
-                        )
+        if not module.check_mode and change_go:
+            go_attr = FileSystemPatch(group_ownership=module.params["group_ownership"])
+            res = system.patch_file_systems(
+                names=[module.params["name"]], file_system=go_attr
+            )
+            if res.status_code != 200:
+                module.fail_json(
+                    msg="Failed to modify group ownership for "
+                    "filesystem {0}. Error: {1}".format(
+                        module.params["name"],
+                        res.errors[0].message,
                     )
+                )
 
     module.exit_json(
-        changed=(changed or change_export or change_share or change_ca or change_go)
+        changed=(
+            changed
+            or change_export
+            or change_share
+            or change_ca
+            or change_go
+            or change_client
+        )
     )
 
 
@@ -994,7 +1002,7 @@ def _delete_fs(module, blade):
             ),
         )
 
-    blade.file_systems.delete_file_systems(module.params["name"])
+    blade.file_systems.delete_file_systems(name=module.params["name"])
 
 
 def delete_fs(module, blade):
@@ -1100,7 +1108,9 @@ def main():
             smb_aclmode=dict(
                 type="str", default="shared", choices=["shared", "native"]
             ),
-            group_ownership=dict(choices=["creator", "parent-directory"]),
+            group_ownership=dict(
+                choices=["creator", "parent-directory"], default="creator"
+            ),
             policy_state=dict(default="present", choices=["present", "absent"]),
             state=dict(default="present", choices=["present", "absent"]),
             delete_link=dict(default=False, type="bool"),
